package unisa.gps.etour.gui.operatoreagenzia;

import java.awt.*;
import java.awt.event.*;
import java.io.FileNotFoundException;
import java.rmi.RemoteException;
import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.tree.*;
import javax.swing.border.*;
import unisa.gps.etour.gui.operatoreagenzia.BannerDialog;
import unisa.gps.etour.gui.operatoreagenzia.Home;
import unisa.gps.etour.gui.operatoreagenzia.TagPanel;
import unisa.gps.etour.gui.operatoreagenzia.tables.BannerNode;
import unisa.gps.etour.gui.operatoreagenzia.tables.PRNode;
import unisa.gps.etour.bean.BeanBanner;
import unisa.gps.etour.bean.BeanPuntoDiRistoro;
import unisa.gps.etour.bean.BeanTag;
import unisa.gps.etour.control.GestioneAdvertisement.IGestioneAdvertisementAgenzia;
import unisa.gps.etour.control.GestionePuntiDiRistoro.IGestionePuntiDiRistoroAgenzia;
import unisa.gps.etour.control.GestioneTag.IGestioneTagComune;
import unisa.gps.etour.gui.DeskManager;
import unisa.gps.etour.gui.HelpManager;
import unisa.gps.etour.gui.operatoreagenzia.tables.BannerRenderer;

/**
 * Questa classe realizza l'interfaccia per la gestione dei banner pubblicitari
 * da parte dell'operatore dell'agenzia.
 * 
 * @author Mario Gallo
 * @version 0.7
 * 
 * &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *         University of Salerno
 */
public class Banner extends JInternalFrame
{

	private JPanel jContentPane = null;
	private JPanel rightPanel = null;
	private JToolBar bannerToolbar = null;
	private JButton btnInserisci = null;
	private JButton btnSostituisci = null;
	private JButton btnElimina = null;
	private JScrollPane jScrollPane = null;
	private JPanel helpPanel = null;
	private JTextPane textGuida = null;
	private TagPanel panelTag = null;
	private JButton btnRicerca = null;
	private JButton btnAzzera = null;
	private JPanel panelSearch = null;
	private JTextField nomePR = null;
	private JTree treeBanner = null;
	private JDesktopPane jDesktopPane;
	private HelpManager bannerHelp;
	protected DeskManager desktopManager;
	protected IGestionePuntiDiRistoroAgenzia gestionePuntiRistoro;
	protected IGestioneAdvertisementAgenzia gestioneBanner;
	protected IGestioneTagComune tag;

	/**
	 * Questo &grave; il costruttore di default.
	 */
	public Banner()
	{
		super("Banner");
		resizable = true;
		closable = true;
		iconable = true;
		maximizable = true;
		setPreferredSize(Home.CHILD_SIZE);
		frameIcon = new ImageIcon(getClass().getResource(
				Home.URL_IMAGES + "banner2.png"));

		// Setting up dell'help manager per beni culturali.

		textGuida = new JTextPane();

		try
		{
			bannerHelp = new HelpManager(Home.URL_HELP + "Banner.txt",
					textGuida);
		}
		catch (FileNotFoundException e)
		{
			textGuida
					.setText("<html><b>Guida in linea non disponibile!</b></html>");
		}

		setContentPane(getJContentPane());
		addInternalFrameListener(new InternalFrameAdapter()
		{
			/*
			 * All'inserimento del frame nel desktop pane recupera il
			 * collegamento al desktop pane.
			 */

			public void internalFrameOpened(InternalFrameEvent pEvent)
			{
				JInternalFrame frame = pEvent.getInternalFrame();
				jDesktopPane = frame.getDesktopPane();
				desktopManager = (DeskManager) jDesktopPane.getDesktopManager();
				
				//Setting up degli oggetti remoti per la gestione dei beni culturali.
				try
				{
					Registry reg = LocateRegistry.getRegistry(Home.HOST);
					gestioneBanner = 
						(IGestioneAdvertisementAgenzia)reg.lookup("GestioneBeniCulturaliAgenzia");
					tag = 
						(IGestioneTagComune)reg.lookup("GestioneTagComune");
					gestionePuntiRistoro =
						(IGestionePuntiDiRistoroAgenzia) reg.lookup("GestionePuntiDiRistoroAgenzia");
					
					//Caricamento dei dati.
					createTree();
					caricaTags();
				}
				/*
				 * Due eccezioni: RemoteException e NotBoundException. Il
				 * risultato è lo stesso. La gestione non è operabile e la
				 * finestra dopo il messaggio di errore verrà chiusa.
				 */
				catch (Exception ex)
				{
					JLabel errore = new JLabel(
							"<html><h2>Impossibile comunicare con il server di eTour.</h2>"
									+ "<h3><u>La finestra di gestione richiesta verrà chiusa.</u></h3>"
									+ "<p><b>Possibili Cause:</b>"
									+ "<ul><li>Nessuna connessione alla rete.</li>"
									+ "<li>Server inattivo.</li>"
									+ "<li>Server intasato.</li></ul>"
									+ "<p>Si prega di riprovare in un secondo momento.</p>"
									+ "<p>Se l'errore dovesse persistere, si prega di contattare l'assistenza tecnica.</p>"
									+ "<p>Ci scusiamo per il disagio.</html>");
					ImageIcon err = new ImageIcon(getClass().getResource(
							Home.URL_IMAGES + "error48.png"));
					JOptionPane.showMessageDialog(jDesktopPane, errore,
							"Errore!", JOptionPane.ERROR_MESSAGE, err);
					frame.dispose();
				}
			}
		});
	}

	/**
	 * Questo metodo inizializza il content pane.
	 * 
	 * @return javax.swing.JPanel - il content pane.
	 */
	private JPanel getJContentPane()
	{
		if (jContentPane == null)
		{
			jContentPane = new JPanel();
			jContentPane.setLayout(new BorderLayout());
			jContentPane.add(getRightPanel(), BorderLayout.EAST);
			jContentPane.add(getBannerToolbar(), BorderLayout.NORTH);
			jContentPane.add(getTreeBanner(), BorderLayout.CENTER);
		}
		return jContentPane;
	}

	/**
	 * Questo metodo inizializza la toolbar per le funzionalit� della gestione
	 * banner.
	 * 
	 * @return javax.swing.JToolBar - la toolbar.
	 */
	private JToolBar getBannerToolbar()
	{
		if (bannerToolbar == null)
		{
			bannerToolbar = new JToolBar();
			bannerToolbar.setLayout(null);
			bannerToolbar.setPreferredSize(new Dimension(1, 50));
			bannerToolbar.setFloatable(false);
			bannerToolbar.add(getBtnInserisci());
			bannerToolbar.add(getBtnSostituisci());
			bannerToolbar.add(getBtnElimina());
		}
		return bannerToolbar;
	}

	/**
	 * Questo metodo inizializza il pulsante per l'inserimento di un banner.
	 * 
	 * @return javax.swing.JButton - il pulsante per l'inserimento.
	 */
	private JButton getBtnInserisci()
	{
		if (btnInserisci == null)
		{
			btnInserisci = new JButton();
			btnInserisci.setBounds(5, 5, 140, 40);
			btnInserisci.setText("<html>Inserisci<br>Banner</html>");
			btnInserisci.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "NuovoBanner32.png")));
			btnInserisci.setEnabled(false);
			btnInserisci.setName("btnInserisci");
			btnInserisci.addMouseListener(bannerHelp);
			btnInserisci.addActionListener(new ActionListener()
			{

				public void actionPerformed(ActionEvent arg0)
				{
					DefaultMutableTreeNode selectedNode = (DefaultMutableTreeNode) treeBanner
							.getSelectionPath().getLastPathComponent();
					openDialog(selectedNode);
				}

			});
		}
		return btnInserisci;
	}

	/**
	 * Questo metodo inizializza il pulsante per la modifica di un banner.
	 * 
	 * @return javax.swing.JButton - il pulsante per la modifica.
	 */
	private JButton getBtnSostituisci()
	{
		if (btnSostituisci == null)
		{
			btnSostituisci = new JButton();
			btnSostituisci.setBounds(155, 5, 140, 40);
			btnSostituisci.setText("<html>Sostituisci<br>Banner</html>");
			btnSostituisci.setEnabled(false);
			btnSostituisci.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "SostituisciBanner32.png")));
			btnSostituisci.setName("btnSostituisci");
			btnSostituisci.addMouseListener(bannerHelp);
			btnSostituisci.addActionListener(new ActionListener()
			{

				public void actionPerformed(ActionEvent arg0)
				{
					DefaultMutableTreeNode selectedNode = (DefaultMutableTreeNode) treeBanner
							.getSelectionPath().getLastPathComponent();
					openDialog(selectedNode);
				}

			});
		}
		return btnSostituisci;
	}

	/**
	 * Questo metodo inizializza il pulsante per l'eliminazione di un banner.
	 * 
	 * @return javax.swing.JButton - il pulsante per l'eliminazione.
	 */
	private JButton getBtnElimina()
	{
		if (btnElimina == null)
		{
			btnElimina = new JButton();
			btnElimina.setBounds(305, 5, 140, 40);
			btnElimina.setText("<html>Elimina<br>Banner</html>");
			btnElimina.setEnabled(false);
			btnElimina.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "EliminaBanner32.png")));
			btnElimina.setName("btnElimina");
			btnElimina.addMouseListener(bannerHelp);
			btnElimina.addActionListener(new ActionListener()
			{

				public void actionPerformed(ActionEvent arg0)
				{
					JPanel root = new JPanel(new BorderLayout());
					JLabel message = new JLabel(
							"Sei sicuro di voler eliminare il banner selezionato?");
					message.setFont(new Font("Dialog", Font.BOLD, 14));
					JLabel avviso = new JLabel(
							"Il banner non potr� essere pi� recuperato.",
							SwingConstants.CENTER);
					avviso.setIcon(new ImageIcon(getClass().getResource(
							Home.URL_IMAGES + "warning16.png")));
					root.add(message, BorderLayout.NORTH);
					root.add(avviso, BorderLayout.SOUTH);
					String[] options = { "Elimina", "Annulla" };
					int scelta = JOptionPane.showInternalOptionDialog(
							jContentPane, root, "Conferma Eliminazione",
							JOptionPane.YES_NO_OPTION,
							JOptionPane.QUESTION_MESSAGE, new ImageIcon(
									getClass().getResource(
											Home.URL_IMAGES
													+ "EliminaBanner48.png")),
							options, options[1]);
					if (scelta == JOptionPane.YES_OPTION)
					{
						DefaultTreeModel modello = (DefaultTreeModel) treeBanner
								.getModel();
						modello
								.removeNodeFromParent((DefaultMutableTreeNode) treeBanner
										.getSelectionPath()
										.getLastPathComponent());
						JLabel confirm = new JLabel("Il banner selezionato"
								+ " è stato eliminato.");
						confirm.setFont(new Font("Dialog", Font.BOLD, 14));
						JOptionPane.showInternalMessageDialog(jContentPane,
								confirm, "Banner eliminato!",
								JOptionPane.OK_OPTION, new ImageIcon(getClass()
										.getResource(
												Home.URL_IMAGES + "ok32.png")));
					}

				}

			});
		}
		return btnElimina;
	}

	/**
	 * Questo metodo crea l'albero partendo dalle informazioni contenuti nei due
	 * arraylist di bean.
	 * 
	 * @param pPR ArrayList<BeanPuntoDiRistoro> - l'array dei punti di ristoro.
	 * @param pBanner ArrayList<BeanBanner> - l'array dei banner associati.
	 */
	private void createTree()
	{
		// Creazione della radice
		DefaultMutableTreeNode root = new DefaultMutableTreeNode("eTour");

		// Per ogni punto di ristoro dell'arraylist chiama il metodo ottieni
		// banner.
		try 
		{
		ArrayList<BeanPuntoDiRistoro> pPR = 
			gestionePuntiRistoro.ottieniPuntiDiRistoro();
		for (int i = 0; i < pPR.size(); i++)
		{
			BeanPuntoDiRistoro corrente = pPR.get(i);
			int id = corrente.getId();
			PRNode puntoDiRistoro = new PRNode(corrente.getNome(), id);
			HashMap<BeanBanner, ImageIcon> banner = gestioneBanner.ottieniBannersDaID(id);
			Iterator<BeanBanner> iteraBanner = banner.keySet().iterator();
			while (iteraBanner.hasNext())
			{
				BeanBanner bannercorrente = iteraBanner.next();
				BannerNode nuovoBanner = new BannerNode(banner
						.get(bannercorrente), bannercorrente.getId());
				puntoDiRistoro.add(nuovoBanner);
			}

			root.add(puntoDiRistoro);
		}
		}
		catch (RemoteException ex)
		{
			JLabel errore = new JLabel(
					"<html><h2>Impossibile comunicare con il server di eTour.</h2>"
							+ "<h3><u>La lista dei banner non è stata caricata.</u></h3>"
							+ "<p>Si prega di riprovare in un secondo momento.</p>"
							+ "<p>Se l'errore dovesse persistere, si prega di contattare l'assistenza tecnica.</p>"
							+ "<p>Ci scusiamo per il disagio.</html>");
			ImageIcon err = new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "error48.png"));
			JOptionPane.showInternalMessageDialog(this, errore,
					"Errore!", JOptionPane.ERROR_MESSAGE, err);
		}
		finally 
		{
			treeBanner.setModel(new DefaultTreeModel(root));
		}
		
	}

	/**
	 * Questo metodo inizializza il tree dove vengono visualizzati il banner.
	 * 
	 * @return javax.swing.JTree
	 */
	private JScrollPane getTreeBanner()
	{

		if (treeBanner == null)
		{
			treeBanner = new JTree(new DefaultTreeModel(new DefaultMutableTreeNode("etour")));
			treeBanner.setScrollsOnExpand(true);
			treeBanner.setAutoscrolls(true);
			treeBanner.setScrollsOnExpand(true);
			treeBanner.getSelectionModel().setSelectionMode(
					TreeSelectionModel.SINGLE_TREE_SELECTION);
			treeBanner.setName("treeBanner");
			treeBanner.addMouseListener(bannerHelp);
			treeBanner.setRootVisible(false);
			treeBanner.setCellRenderer(new BannerRenderer());
			treeBanner.addTreeSelectionListener(new TreeSelectionListener()
			{
				public void valueChanged(TreeSelectionEvent e)
				{
					DefaultMutableTreeNode node = (DefaultMutableTreeNode) treeBanner
							.getLastSelectedPathComponent();

					if (node instanceof PRNode)
					{
						btnInserisci.setEnabled(true);
						btnElimina.setEnabled(false);
						btnSostituisci.setEnabled(false);
					}
					else if (node instanceof BannerNode)
					{
						btnInserisci.setEnabled(false);
						btnSostituisci.setEnabled(true);
						btnElimina.setEnabled(true);
					}
					else
					{
						btnInserisci.setEnabled(false);
						btnSostituisci.setEnabled(false);
						btnElimina.setEnabled(false);
					}

				}
			});

		}
		jScrollPane = new JScrollPane(treeBanner);
		jScrollPane
				.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		return jScrollPane;
	}

	/**
	 * Questo metodo inizializza il pannello laterale destro.
	 * 
	 * @return javax.swing.JPanel - il pannello destro.
	 */
	private JPanel getRightPanel()
	{
		if (rightPanel == null)
		{
			rightPanel = new JPanel();
			rightPanel.setLayout(new GridBagLayout());
			GridBagConstraints g = new GridBagConstraints();
			g.gridx = 0;
			g.gridy = 0;
			g.fill = GridBagConstraints.BOTH;
			g.weighty = 0.7;
			rightPanel.add(getSearchPanel(), g);
			g.gridy++;
			g.weighty = 0.3;
			rightPanel.add(getHelpPanel(), g);
		}
		return rightPanel;
	}

	/**
	 * Questo metodo inizializza il pannello che contiene la guida in linea.
	 * 
	 * @return javax.swing.JPanel - il pannello per la guida.
	 */
	private JPanel getHelpPanel()
	{
		if (helpPanel == null)
		{
			helpPanel = new JPanel();
			helpPanel.setLayout(new BorderLayout());
			helpPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory
					.createLineBorder(new Color(51, 102, 255), 3),
					"Guida in Linea", TitledBorder.DEFAULT_JUSTIFICATION,
					TitledBorder.DEFAULT_POSITION, new Font("Dialog",
							Font.BOLD, 12), new Color(0, 102, 204)));
			helpPanel.setPreferredSize(new Dimension(200, 60));
			textGuida.setPreferredSize(new Dimension(6, 30));
			textGuida.setOpaque(false);
			textGuida.setContentType("text/html");
			textGuida.setText("<html>Muovi il puntatore del mouse su un controllo " +
				"d'interesse per visualizzare la guida sensibile al contesto.</html>");
			textGuida.setEditable(false);
			textGuida.setName("textGuida");
			textGuida.addMouseListener(bannerHelp);
			helpPanel.add(textGuida, BorderLayout.CENTER);
		}
		return helpPanel;
	}

	/**
	 * Questo metodo inizializza il pannello per la ricerca dei punti di
	 * ristoro.
	 * 
	 * @return javax.swing.JPanel - il pannello per la ricerca.
	 */
	private JPanel getSearchPanel()
	{
		if (panelSearch == null)
		{
			panelSearch = new JPanel();
			panelSearch.setLayout(new GridBagLayout());
			panelSearch.setBorder(BorderFactory.createTitledBorder(
					BorderFactory.createLineBorder(new Color(51, 102, 255), 3),
					"Ricerca Punto di Ristoro",
					TitledBorder.DEFAULT_JUSTIFICATION,
					TitledBorder.DEFAULT_POSITION, new Font("Dialog",
							Font.BOLD, 12), new Color(0, 102, 204)));
			GridBagConstraints g = new GridBagConstraints();
			g.anchor = GridBagConstraints.CENTER;
			g.gridx = 0;
			g.gridy = 0;
			g.gridwidth = 2;
			g.insets = new Insets(5, 5, 5, 5);
			panelSearch.add(new JLabel("Nome Punto di Ristoro:"), g);
			nomePR = new JTextField();
			nomePR.setName("nomePR");
			nomePR.addMouseListener(bannerHelp);
			nomePR.setColumns(12);
			g.insets = new Insets(5, 5, 10, 5);
			g.gridy++;
			panelSearch.add(nomePR, g);
			g.insets = new Insets(5, 5, 5, 5);
			g.gridy++;
			panelSearch.add(new JLabel("Seleziona tag di ricerca:"), g);
			g.weighty = 1.0;
			g.insets = new Insets(5, 5, 10, 5);
			g.gridy++;
			panelTag = new TagPanel();
			panelTag.setName("pannelloTag");
			panelTag.addMouseListener(bannerHelp);
			panelTag.setPreferredSize(new Dimension(180, 10));
			g.fill = GridBagConstraints.VERTICAL;
			panelSearch.add(panelTag, g);
			g.fill = GridBagConstraints.NONE;
			g.insets = new Insets(5, 5, 5, 5);
			g.weighty = 0;
			g.gridy++;
			g.gridwidth = 1;
			panelSearch.add(getBtnRicerca(), g);
			g.gridx++;
			panelSearch.add(getBtnAzzera(), g);
		}
		return panelSearch;
	}

	/**
	 * Questo metodo inizializza il pulsante per la sottomissione della form di
	 * ricerca di un punto di ristoro.
	 * 
	 * @return javax.swing.JButton - il pulsante di ricerca.
	 */
	private JButton getBtnRicerca()
	{
		if (btnRicerca == null)
		{
			btnRicerca = new JButton();
			btnRicerca.setPreferredSize(new Dimension(98, 26));
			btnRicerca.setText("Ricerca");
			btnRicerca.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "Ricerca16.png")));
			btnRicerca.setName("btnRicerca");
			btnRicerca.addMouseListener(bannerHelp);
		}
		return btnRicerca;
	}

	/**
	 * Questo metodo inizializza il pulsante per l'azzeramento dei campi della
	 * form di ricerca di un punto di ristoro.
	 * 
	 * @return javax.swing.JButton - il pulsante azzera.
	 */
	private JButton getBtnAzzera()
	{
		if (btnAzzera == null)
		{
			btnAzzera = new JButton();
			btnAzzera.setPreferredSize(new Dimension(98, 26));
			btnAzzera.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "Azzera16.png")));
			btnAzzera.setText("Azzera");
			btnAzzera.setHorizontalTextPosition(SwingConstants.LEADING);
			btnAzzera.setName("btnAzzera");
			btnAzzera.addMouseListener(bannerHelp);
			btnAzzera.addActionListener(new ActionListener()
			{

				public void actionPerformed(ActionEvent arg0)
				{
					panelTag.azzera();
					nomePR.setText("");
				}

			});
		}
		return btnAzzera;
	}
	
	/**
	 * Questo metodo apre la dialog box per l'inserimento di un nuovo 
	 * banner o per la modifica di un banner selezionato.
	 *
	 * @param pSelectedNode DefaultMutableTreeNode - il nodo selezionato.
	 */
	private void openDialog(DefaultMutableTreeNode pSelectedNode)
	{
		// Questa classe intercetta gli eventi del mouse e quindi
		// rende il frame sottostante bloccato.
		class ModalAdapter extends InternalFrameAdapter
		{
			Component glass;

			public ModalAdapter(Component pGlassComponent)
			{
				this.glass = pGlassComponent;

				MouseInputAdapter adapter = new MouseInputAdapter()
				{
				};
				pGlassComponent.addMouseListener(adapter);
				pGlassComponent.addMouseMotionListener(adapter);
			}

			public void internalFrameClosed(InternalFrameEvent e)
			{
				glass.setVisible(false);
			}
		}

		// Costruzione della dialog
		JOptionPane optionPane = new JOptionPane();
		final JInternalFrame modal = optionPane.createInternalFrame(
				jDesktopPane, "");
		final JPanel glass = new JPanel();
		final BannerDialog dialogo = new BannerDialog();
		optionPane.setMessage(dialogo);
		optionPane.setMessageType(JOptionPane.INFORMATION_MESSAGE);
		JButton[] options = new JButton[2];
		options[0] = new JButton();
		options[1] = new JButton("Annulla");
		options[0].setIcon(new ImageIcon(getClass().getResource(
				Home.URL_IMAGES + "Salva16.png")));
		options[1].setIcon(new ImageIcon(getClass().getResource(
				Home.URL_IMAGES + "Annulla16.png")));
		optionPane.setOptions(options);
		options[1].addActionListener(new ActionListener()
		{
			public void actionPerformed(ActionEvent arg0)
			{
				modal.setVisible(false);
				glass.setVisible(false);
			}
		});

		glass.setOpaque(false);
		modal.addInternalFrameListener(new ModalAdapter(glass));
		glass.add(modal);
		setGlassPane(glass);
		modal.setLocation(this.getWidth() / 2, this.getHeight() / 2);
		glass.setVisible(true);
		modal.setVisible(true);
		if (pSelectedNode instanceof BannerNode) // Sostituzione
		{
			final BannerNode banner = (BannerNode) pSelectedNode;
			options[0].setText("Sostituisci");
			options[0].addActionListener(new ActionListener()
			{

				public void actionPerformed(ActionEvent arg0)
				{
					DefaultTreeModel model = (DefaultTreeModel) treeBanner
							.getModel();
					banner.setBanner(dialogo.getSelectedBanner());
					model.nodeChanged(banner);
					glass.setVisible(false);
					modal.setVisible(false);
				}

			});

			optionPane.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "SostituisciBanner48.png")));
			modal.setTitle("Sostituisci banner per il punto di ristoro "
					+ ((PRNode) pSelectedNode.getParent()).getUserObject()
							.toString());
		}
		else if (pSelectedNode instanceof PRNode) // Inserimento
		{
			final PRNode pr = (PRNode) pSelectedNode;
			options[0].setText("Salva");
			options[0].addActionListener(new ActionListener()
			{

				public void actionPerformed(ActionEvent arg0)
				{
					DefaultTreeModel model = (DefaultTreeModel) treeBanner
							.getModel();
					BannerNode nuovo = new BannerNode(dialogo
							.getSelectedBanner(), pr.getID());
					model.insertNodeInto(nuovo, pr, 0);
					glass.setVisible(false);
					modal.setVisible(false);
				}

			});
			optionPane.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "nuovoBanner48.png")));
			modal.setTitle("Inserisci banner per il punto di ristoro "
					+ pSelectedNode.getUserObject().toString());
		}

	}
	
	private void caricaTags()
	{
		ArrayList<BeanTag> beanTags = null;
		try
		{
			beanTags = tag.ottieniTags();
		}
		// In caso di errore visualizza un messaggio di errore.
		catch (RemoteException e)
		{
		}
		finally 
		{
			for (BeanTag b: beanTags)
			{
				panelTag.insertTag(b);
			}
			panelTag.repaint();	
		}
		
	}
}
