package unisa.gps.etour.gui.operatoreagenzia.tables;

import javax.swing.ImageIcon;
import javax.swing.tree.DefaultMutableTreeNode;

/**
 * Questa classe realizza un nodo di un jtree per memorizzare
 * le informazioni relative a un banner.
 * 
 * @version 1.0
 * @author Mario Gallo
 * 
 * &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *         University of Salerno 
 */
public class BannerNode extends DefaultMutableTreeNode
{
	private int id;

	/**
	 * Questo è il costruttore di default.
	 *
	 */
	public BannerNode()
	{
		super();
	}
	
	/**
	 * Crea un nodo con l'immagine del banner e 
	 * il suo id forniti come parametri.
	 * 
	 * @param pBanner ImageIcon - l'immagine del banner.
	 * @param pID int - l'id del banner.
	 * @throws IllegalArgumentException - se l'immagine fornita in input non è valido.
	 * 
	 */
	public BannerNode(ImageIcon pBanner, int pID) throws IllegalArgumentException
	{
		super();
		if (pBanner == null)
		{
			throw new IllegalArgumentException("Immagine fornita non valida.");
		}
		setUserObject(pBanner);
		id = pID;
	}
	
	/**
	 * 
	 *	Restituisce il nodo di tipo PRNode padre. 
	 *
	 *	@return PRNode - il nodo padre.
	 *
	 */
	public PRNode getParent()
	{
		return (PRNode)super.getParent();
	}
	
	/**
	 * 
	 * Restituisce l'id del banner le cui informazioni
	 * sono memorizzate in questo nodo.
	 *
	 * @return int - l'id del banner.
	 * 
	 */
	public int getID()
	{
		return id;
	}
	
	/**
	 * 
	 * Memorizza l'id del banner fornito in input.
	 *
	 * @param pID int - un id di un banner.
	 * 
	 */
	public void setID(int pID)
	{
		id = pID;
	}
	
	/**
	 * 
	 * Restituisce l'immagine del banner.
	 *
	 * @return ImageIcon - l'immagine.
	 */
	public ImageIcon getBanner()
	{
		return (ImageIcon) getUserObject();
	}
	
	/**
	 * 
	 * Memorizza l'immagine fornita in input.
	 *
	 * @param pImmagine ImageIcon - l'immagine da memorizzare.
	 * @throws IllegalArgumentException - se il parametro fornito è null.
	 */
	public void setBanner(ImageIcon pImmagine) throws IllegalArgumentException
	{
		if (pImmagine == null)
		{
			throw new IllegalArgumentException("Immagine fornita non valida.");
		}
		setUserObject(pImmagine);
	}
}
