﻿package unisa.gps.etour.util;

import java.awt.image.BufferedImage;
import java.util.Date;

import javax.swing.ImageIcon;

import unisa.gps.etour.bean.BeanBanner;
import unisa.gps.etour.bean.BeanBeneCulturale;
import unisa.gps.etour.bean.BeanConvenzione;
import unisa.gps.etour.bean.BeanMenu;
import unisa.gps.etour.bean.BeanNews;
import unisa.gps.etour.bean.BeanOperatorePuntoDiRistoro;
import unisa.gps.etour.bean.BeanPiatto;
import unisa.gps.etour.bean.BeanPreferenzaDiRicerca;
import unisa.gps.etour.bean.BeanPreferenzeGeneriche;
import unisa.gps.etour.bean.BeanPuntoDiRistoro;
import unisa.gps.etour.bean.BeanTag;
import unisa.gps.etour.bean.BeanTurista;
import unisa.gps.etour.bean.BeanVisitaBC;
import unisa.gps.etour.bean.BeanVisitaPR;

/**
 * Classe per la gestione del controllo della correttezza delle stringhe
 * 
 * @author Penna Giuseppe
 * @version 0.1 &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *          University of Salerno
 */
public class ControlloDati
{

	private final static String lettere = "abcdefghijklmnopqrstuvxywz"
			+ "ABCDEFGHIJKLMNOPQRSTUVXYWZ";
	private final static String numeri = "0123456789";

	public final static int LUNGHEZZA_MASSIMA = 64;

	/**
	 * Metodo statico per il controllo di correttezza di una Stringa
	 * 
	 * @param pStringa Stringa da controllare
	 * @param letterePermesse Booleano: True se è consentita la presenza di
	 *            lettere nella stringa, False altrimenti
	 * @param numeriPermessi Booleano: True se è consentita la presenza di
	 *            numeri nella stringa, False altrimenti
	 * @param caratteriPermessi Stringa contenente l'insieme dei caratteri
	 *            consentiti nella stringa
	 * @param caratteriNecessari Stringa contentente l'insieme dei caratteri che
	 *            devono essere presenti nella stringa
	 * @param numeroCaratteriMin Intero rappresentante il numero minimo di
	 *            caratteri consentiti nella stringa
	 * @param numeroCaratteriMax Intero rappresentante il numero massimo di
	 *            caretteri consentiti nella stringa
	 * @return Booleano: True se la striga rispetta le condizioni, False
	 *         altrimenti
	 */
	public static boolean controllaStringa(String pStringa,
			boolean letterePermesse, boolean numeriPermessi,
			String caratteriPermessi, String caratteriNecessari,
			int numeroCaratteriMin, int numeroCaratteriMax)
	{
		// Caso pStringa == null: la funzione ritorna falso
		if (pStringa == null)
			return false;

		int lunghezzaStringa = pStringa.length();
		Character carattereCorrente;

		// Controllo sulla lunghezza della stringa
		if (lunghezzaStringa < numeroCaratteriMin
				|| lunghezzaStringa > numeroCaratteriMax)
		{
			return false;
		}

		// Controllo sulla presenza dei caratteri necessari nella stringa
		if (caratteriNecessari != null)
		{
			if (!caratteriNecessari.equals(""))
				for (int i = 0; i < caratteriNecessari.length(); i++)
				{
					carattereCorrente = caratteriNecessari.charAt(i);
					if (!pStringa.contains(carattereCorrente.toString()))
					{
						return false;
					}
				}
		}

		// Creazione della stringa contenente tutti i caratteri consentiti
		String stringaCaratteriPermessi = caratteriPermessi
				+ caratteriNecessari + (letterePermesse ? lettere : "")
				+ (numeriPermessi ? numeri : "");

		// Ciclo per l'ispezione dei caratteri della stringa da controllare
		for (int i = 0; i < lunghezzaStringa; i++)
		{

			carattereCorrente = pStringa.charAt(i);

			// Condizione: se il carattere che si sta controllando non è
			// presente nella stringa dei caratteri permessi
			// la stringa è incorretta ed esce dal ciclo.
			if (!(stringaCaratteriPermessi.contains(carattereCorrente
					.toString())))
			{

				return false;
			}
		}

		return true;
	}

	public static String correggiStringa(String pStringa,
			boolean letterePermesse, boolean numeriPermessi,
			String caratteriPermessi, int numeroCaratteriMax)
	{

		if (pStringa == null)
			return null;

		String stringaCaratteriPermessi = caratteriPermessi
				+ (letterePermesse ? lettere : "")
				+ (numeriPermessi ? numeri : "");

		Character carattereCorrente;
		int lunghezzaStringa = pStringa.length();
		int i = 0;

		while (i < lunghezzaStringa)
		{
			carattereCorrente = pStringa.charAt(i);

			if (!(stringaCaratteriPermessi.contains(carattereCorrente
					.toString())))
			{
				pStringa = pStringa.replaceAll("\\"
						+ carattereCorrente.toString(), "");
				lunghezzaStringa = pStringa.length();

			}
			else
				i++;
		}
		if (lunghezzaStringa > numeroCaratteriMax)
		{

			pStringa = pStringa.substring(0, numeroCaratteriMax);
		}

		return pStringa;
	}

	public static boolean controllaData(String pData)
	{
		// Ancora non ho idea di come mi passeranno la data
		return true;
	}

	public static boolean controllaDate(Date pDataInizio, Date pDataFine)
	{

		boolean ritorno = false;
		if (pDataInizio != null && pDataFine != null)
		{

			if (pDataInizio.before(pDataFine))
				ritorno = true;
		}

		return ritorno;
	}

	public static boolean checkBeanTurista(BeanTurista pTurista)
	{
		if (pTurista != null && pTurista instanceof BeanTurista)
			return true;
		return false;
	}

	public static boolean checkBeanPreferenzaDiRicerca(
			BeanPreferenzaDiRicerca pPreferenzaDiRicerca)
	{
		if (pPreferenzaDiRicerca != null
				&& pPreferenzaDiRicerca instanceof BeanPreferenzaDiRicerca)
			return true;
		return true;
	}

	public static boolean checkBeanPreferenzeGeneriche(
			BeanPreferenzeGeneriche pPreferenzeGeneriche)
	{
		if (pPreferenzeGeneriche != null
				&& pPreferenzeGeneriche instanceof BeanPreferenzeGeneriche)
			return true;
		return false;
	}

	public static boolean checkBeanBeneCulturale(
			BeanBeneCulturale pBeneCulturale)
	{
		if (pBeneCulturale != null
				&& pBeneCulturale instanceof BeanBeneCulturale)
			return true;
		return false;
	}

	public static boolean checkBeanPuntoDiRistoto(
			BeanPuntoDiRistoro pPuntoDiRistoro)
	{
		if (pPuntoDiRistoro != null
				&& pPuntoDiRistoro instanceof BeanPuntoDiRistoro)
			return true;
		return false;
	}

	public static boolean checkBeanOperatorePuntoDiRistoro(
			BeanOperatorePuntoDiRistoro pOperaotorePuntoDiRistoro)
	{
		if (pOperaotorePuntoDiRistoro != null
				&& pOperaotorePuntoDiRistoro instanceof BeanOperatorePuntoDiRistoro)
			return true;
		return false;
	}

	/**
	 * Effettua il controllo formale e di consistenza sui dati del banner
	 * contenuto nel bean passato per parametro.
	 * 
	 * @author Palladino Fabio
	 * @param pBanner bean contenente i dati del banner.
	 * @return True se i dati del banner sono corretti false altrimenti.
	 */
	public static boolean checkBeanBanner(BeanBanner pBanner)
	{
		boolean toReturn = false;

		if (pBanner != null && pBanner instanceof BeanBanner)
		{
			toReturn = (pBanner.getId() > 0 && pBanner.getPercorsoFile() != "" && pBanner
					.getIdPuntoDiRistoro() > 0);
		}

		return toReturn;
	}

	/**
	 * Metodo che controlla l'immagine contenuta nell'oggetto ImageIcon passato
	 * per parametro.
	 * 
	 * @author Palladino Fabio
	 * @param immagine oggetto ImageIcon contenente l'immagine da controllare
	 * @return true se l'immagine contenuta nell'oggetto ImageIcon è una istanza
	 *         della classe BufferedImage.
	 */
	public static boolean checkImmagine(ImageIcon immagine)
	{

		if (immagine != null)
		{
			return (immagine.getImage() instanceof BufferedImage);
		}
		return false;
	}

	/**
	 * Funzione che controlla i dati di una news;
	 * 
	 * @author Palladino Fabio
	 * @param pNews bean contenete i dati di una news.
	 * @return
	 */
	public static boolean checkBeanNews(BeanNews pNews)
	{
		boolean toReturn = false;

		/* Controllo sulla validità generale del parametro del metodo */
		if (pNews != null)
		{

			Date dataPubb = pNews.getDataPubblicazione(); // Data di
															// pubblicazione
			Date dataScad = pNews.getDataScadenza(); // Data scadenza
			String news = pNews.getNews(); // Testo della News
			int priority = pNews.getPriorita();

			/* Controllo sulla nullità dei campi */
			if (dataPubb != null && dataScad != null && news != null)
			{
				/* Controllo sulla coerenza delle date */
				toReturn = dataPubb.before(dataScad);
				/* Controlla che il testo non sia vuoto */
				toReturn = toReturn && (news != "");
				/* Controlla che l'id sia maggiore di 0 */
				toReturn = toReturn && (pNews.getId() > 0);
				/* Controlla il valore della priorità */
				toReturn = toReturn
						&& (priority <= CostantiGlobali.MAX_PRIORITY_NEWS)
						&& (priority >= CostantiGlobali.MIN_PRIORITY_NEWS);
			}
		}
		return toReturn;
	}

	public static boolean checkBeanTag(BeanTag pTag)
	{
		if (pTag != null && pTag instanceof BeanTag)
			return true;
		return false;
	}

	public static boolean checkBeanConvenzione(BeanConvenzione pConvenzione)
	{
		if (pConvenzione != null && pConvenzione instanceof BeanConvenzione)
			return true;
		return false;
	}

	public static boolean checkBeanMenu(BeanMenu pMenu)
	{
		if (pMenu != null && pMenu instanceof BeanMenu)
			return true;
		return false;
	}

	public static boolean checkBeanPiatto(BeanPiatto pPiatto)
	{
		if (pPiatto != null && pPiatto instanceof BeanPiatto)
			return true;
		return false;
	}

	public static boolean checkBeanVisitaBC(BeanVisitaBC pVisitaBC)
	{
		if (pVisitaBC != null && pVisitaBC instanceof BeanVisitaBC)
			return true;
		return false;
	}

	public static boolean checkBeanVisitaPR(BeanVisitaPR pVisitaPR)
	{
		if (pVisitaPR != null && pVisitaPR instanceof BeanVisitaPR)
			return true;
		return false;
	}
}
