package unisa.gps.etour.control.GestioneBeniCulturali;

import unisa.gps.etour.bean.BeanVisitaBC;

/**
 * Questa classe ha il compito di controllare i dati di una visita di bene culturale.
 * Vengono effettuati vari controlli di consistenza quali la lunghezza di stringhe,
 * riferimenti nulli, tipi dinamici errati.
 *
 * @author De Simone Michelangelo
 * @version 0.1
 * 
 *  &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI - University of Salerno
 */
public class ControlloVisiteBeniCulturali
{
	/**
	 * 
	 * Effettua il controllo di consistenza richiamando gli opportuni metodi
	 *
	 * @param pVBC Il bean visita bene culturale da controllare
	 * @return boolean Il risultato del controllo: true se OK, false altrimenti
	 */
	public static boolean controllaDatiVisitaBeneCulturale(BeanVisitaBC pVBC)
	{
		// Se il bean è nullo
		if (pVBC == null || !(pVBC instanceof BeanVisitaBC))
			return false;
		
		// Controlla l'Id della visita bene culturale
		// e l'id del relativo turista
		if (!(pVBC.getIdBeneCulturale() > 0) || !(pVBC.getIdTurista() > 0))
			return false;
		
		// Controlla il voto (ovviamente sono accettati soltanto voti compresi tra 1 e 5
		if (!(pVBC.getVoto() >= 1 && pVBC.getVoto() <= 5))
			return false;
		
		// Controlla per riferimenti nulli nel bean
		if (!controllaDatiNulli(pVBC))
			return false;
		
		// Controlla la corretta lunghezza delle stringhe
		if (!(pVBC.getCommento().length() > 0))
			return false;
		
		return true;
	}

	/**
	 * 
	 * Controlla la presenza di dati nulli in un bean visita bene culturale
	 *
	 * @param pBC Il bean visita bene culturale da controllare
	 * @return boolean Il risultato del controllo: true se non ci sono riferimenti nulli; false altrimenti
	 */
	public static boolean controllaDatiNulli(BeanVisitaBC pBC)
	{
		// Controllo sulla nullit&agrave; dei campi del feedback
		if (pBC.getCommento() == null || pBC.getDataVisita() == null)
			return false;

		return true;
	}
}
