package unisa.gps.etour.repository;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Classe che realizza la connessione con il database utilizzando jdbc e
 * consente di eseguire query sia di lettura che di modifica del contenuto del
 * database. E' implementata per fornire un pool di connessioni in modo da
 * fornire una connessione ad ogni thread.
 * 
 * @author Miranda Mauro
 * @version 0.1 � 2007 eTour Project - Copyright by SE@SA Lab DMI � University
 *          of Salerno
 */
public class DBConnessionePool
{
	private final static String driver = "com.mysql.jdbc.Driver";
	private final static String urlConnessione = "jdbc:mysql://localhost/eTour?user=mauro&password=mauro";
	private static List<Connection> connessioniLibere;

	/* Costruttore privato che avvia la connessione con il database */

	/*
	 * Blocco di inizializzazione statico utilizzato per caricare il driver in
	 * memoria
	 */
	static
	{
		connessioniLibere = new ArrayList<Connection>();
		try
		{
			Class.forName(driver);
		}
		catch (ClassNotFoundException e)
		{
			e.printStackTrace();
		}
	}

	/**
	 * Metodo per ottenere la connessione al server.
	 * 
	 * @return Restituisce la connessione al database
	 * @throws SQLException
	 */
	public static synchronized Connection ottieniConnessione()
			throws SQLException
	{
		Connection connection;

		if (!connessioniLibere.isEmpty())
		{
			// Extract a connection from the free db connection queue
			connection = connessioniLibere.get(0);
			DBConnessionePool.connessioniLibere.remove(0);

			try
			{
				// If the connection is not valid, a new connection will be
				// analyzed
				if (connection.isClosed())
					connection = DBConnessionePool.ottieniConnessione();
			}
			catch (SQLException e)
			{
				connection = DBConnessionePool.ottieniConnessione();
			}
		}
		else
			// The free db connection queue is empty, so a new connection will
			// be created
			connection = DBConnessionePool.creaDBConnessione();

		return connection;
	}

	public static void rilasciaConnessione(Connection pReleasedConnection)
	{
		// Add the connection to the free db connection queue
		DBConnessionePool.connessioniLibere.add(pReleasedConnection);
	}

	private static Connection creaDBConnessione() throws SQLException
	{
		Connection nuovaConnessione = null;
		// Create a new db connection using the db properties
		nuovaConnessione = DriverManager.getConnection(urlConnessione);
		nuovaConnessione.setAutoCommit(true);
		return nuovaConnessione;
	}
}
