package unisa.gps.etour.gui;

import java.awt.Dimension;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.beans.PropertyVetoException;
import java.util.Iterator;
import java.util.Vector;
import javax.swing.DefaultDesktopManager;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JDesktopPane;
import javax.swing.JInternalFrame;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import unisa.gps.etour.gui.operatoreagenzia.IScheda;

/**
 * Classe per la gestione personalizzata degli internal frame inseriti in un
 * JDesktopPane.
 * 
 * @version 0.1
 * @author Mario Gallo 
 * 
 * &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *         University of Salerno
 */
public class DeskManager extends DefaultDesktopManager
{
	private static final String URL_IMAGES = "/unisa/gps/etour/gui/images/";
	private JPopupMenu deskMenu;
	private JMenuItem riduciTutti;
	private JMenuItem ripristinaTutti;
	private JMenuItem chiudiTutti;
	private Vector<JInternalFrame> iconifiedFrames;
	private int locationX;
	private int locationY;

	/**
	 * Costruttore di default.
	 */
	public DeskManager()
	{
		super();
		iconifiedFrames = new Vector<JInternalFrame>();
		initializeDeskMenu();
		locationX = 0;
		locationY = -1;
	}

	/**
	 * Gestisce lo spostamento dei JInternalFrame all'interno dell'area del
	 * JDesktopPane, impedendo che i frame escano fuori dalla area visibile.
	 * 
	 * @param javax.swing.JComponent aComponent - il componente del quale
	 *            gestire lo spostamento.
	 * @param int x - cordinata x del punto in cui &egrave; stato spostato il
	 *            componente.
	 * @param int y - cordinata y del punto in cui &egrave; stato spostato il
	 *            componente.
	 */
	public void dragFrame(JComponent aComponent, int x, int y)
	{
		if (aComponent instanceof JInternalFrame)
		{
			JInternalFrame frame = (JInternalFrame) aComponent;
			if (frame.isIcon())
			{
				x = frame.getLocation().x;
				y = frame.getLocation().y;
			}
			else
			{
				JDesktopPane desk = frame.getDesktopPane();
				Dimension d = desk.getSize();
				if (x < 0)
				{
					x = 0;
				}

				else
				{
					if (x + frame.getWidth() > d.width)
					{
						x = d.width - frame.getWidth();
					}
				}

				if (y < 0)
				{
					y = 0;
				}
				else
				{
					if (y + frame.getHeight() > d.height)
					{
						y = d.height - frame.getHeight();
					}
				}
			}
		}

		super.dragFrame(aComponent, x, y);
	}

	/**
	 * Personalizza l'azione di riduzione ad icona degli JInternalFrame, creando
	 * delle barre cliccabili sul fondo del JDesktopPane.
	 *
	 * @param JInternalFrame frame - un frame interno ad un
	 *            JDesktopPane.
	 */
	public void iconifyFrame(JInternalFrame frame)
	{
		try
		{
			JDesktopPane desk = frame.getDesktopPane();
			Dimension d = desk.getSize();
			frame.setClosable(false);
			frame.setMaximizable(true);
			frame.setIconifiable(false);
			Rectangle caratteristiche;
			if (frame.isMaximum())
			{
				caratteristiche = frame.getNormalBounds();
			}
			else
				caratteristiche = frame.getBounds();
			frame.setSize(200, 30);
			setPreviousBounds(frame, caratteristiche);
			if (iconifiedFrames.isEmpty())
			{
				locationX = 0;
			}
			else
			{
				locationX += 200;
			}
			if (locationY == -1)
			{
				locationY = d.height - 30;
			}
			if (locationX + 200 > d.width)
			{
				locationX = 0;
				locationY -= 30;
			}
			frame.setLocation(locationX, locationY);
			frame.setResizable(false);
			iconifiedFrames.add(frame);
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Ripristina il frame dall'azione di riduzione a icona, reimpostando la
	 * posizione e la grandezza che aveva prima.
	 *
	 * @param javax.swing.JInternalFrame frame - un frame interno a un
	 *            JDesktopPane.
	 */
	public void deiconifyFrame(JInternalFrame frame)
	{
		try
		{
			JDesktopPane desk = frame.getDesktopPane();
			Dimension deskSize = desk.getSize();
			iconifiedFrames.remove(frame);
			Rectangle caratteristiche = getPreviousBounds(frame);
			if (caratteristiche.width > deskSize.width)
			{
				caratteristiche.width = deskSize.width;
				caratteristiche.x = 0;
			}
			if (caratteristiche.width + caratteristiche.x > deskSize.width)
			{
				caratteristiche.x = (deskSize.width - caratteristiche.width) / 2;
			}
			if (caratteristiche.height > deskSize.height)
			{
				caratteristiche.height = deskSize.height;
				caratteristiche.y = 0;
			}
			if (caratteristiche.height + caratteristiche.y > deskSize.height)
			{
				caratteristiche.y = (deskSize.height - caratteristiche.height) / 2;
			}
			frame.setSize(caratteristiche.width, caratteristiche.height);
			frame.setLocation(caratteristiche.x, caratteristiche.y);
			frame.setIconifiable(true);
			frame.setClosable(true);
			if (frame instanceof IScheda)
			{
				frame.setMaximizable(false);
				frame.setResizable(false);
			}
			else
			{
				frame.setMaximizable(true);
				frame.setResizable(true);
			}
			locationX -= 200;
			if (locationX < 0)
			{
				locationX = deskSize.width / 200 - 200;
				if (locationY != deskSize.height - 30)
				{
					locationY -= 30;
				}
			}
			repaintIconifiedFrames(desk);
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Restituisce il focus a un frame selezionato, e, nel caso in cui il frame
	 * sia iconificato, lo deiconifica.
	 * 
	 * @param frame JInternalFrame - un frame all'interno di un
	 *            JDesktopPane
	 */
	public void activateFrame(JInternalFrame frame)
	{
		try
		{
			if (frame.isIcon())
				frame.setIcon(false);
			frame.setSelected(true);
			super.activateFrame(frame);
		}
		catch (PropertyVetoException e)
		{
			e.printStackTrace();
		}

	}

	/**
	 * Centra il frame fornito come parametro nel JDesktopPane.
	 * 
	 * @param javax.swing.JInternalFrame frame - un frame interno ad un
	 *            JDesktopPane.
	 * @return void
	 */
	public void centerFrame(JInternalFrame frame)
	{
		JDesktopPane desk = frame.getDesktopPane();
		Dimension d = desk.getSize();
		Dimension f = frame.getSize();
		frame.setLocation(d.width / 2 - f.width / 2, d.height / 2 - f.height
				/ 2);
	}

	/**
	 * Ridisegna i frames iconificati presenti nel desktop pane fornito.
	 * 
	 * @param javax.swing.JDesktopPane desk - un desktop pane associato a un
	 *            desk manager.
	 * @throws IllegalArgumentException - &egrave; stato fornito come parametro un
	 *             JDesktopPane a cui non &egrave; associato un Desk Manager.
	 */
	public void repaintIconifiedFrames(JDesktopPane desk)
			throws IllegalArgumentException
	{
		if (desk.getDesktopManager() != this)
			throw new IllegalArgumentException(
					"Non � stato trovato nessun oggetto"
							+ "di tipo DeskManager associato!");
		Iterator<JInternalFrame> iconificati = iconifiedFrames.iterator();
		int i = 0;
		int xLocation;
		int yLocation = desk.getHeight() - 30;
		while (iconificati.hasNext())
		{
			JInternalFrame corrente = iconificati.next();
			xLocation = 200 * i;
			if (xLocation + 200 >= desk.getWidth())
			{
				xLocation = 0;
				yLocation -= 30;
				i = 0;
			}
			corrente.setLocation(xLocation, yLocation);
			i++;
		}
	}

	/**
	 * Ridisegna ( e se necessario ridimensiona ) tutti i frame contenuti in un
	 * dato JDesktopPane.
	 * 
	 * @param javax.swing.JDesktopPane desk - un desktop pane.
	 * @throws IllegalArgumentException - se il desktop pane fornito non &egrave;
	 *             associato a un desktop manager di tipo DeskManager.
	 */
	public void repaintAllFrames(JDesktopPane desk)
			throws IllegalArgumentException
	{
		if (desk.getDesktopManager() != this)
			throw new IllegalArgumentException(
					"Non � stato trovato nessun oggetto"
							+ "di tipo DeskManager associato!");
		JInternalFrame[] frames = desk.getAllFrames();
		Dimension deskSize = desk.getSize();
		for (int i = 0; i < frames.length; i++)
		{
			JInternalFrame corrente = frames[i];
			if (!corrente.isIcon())
			{
				Rectangle frameBounds = corrente.getBounds();
				if (frameBounds.width > deskSize.width)
					frameBounds.width = deskSize.width;
				if (frameBounds.height > deskSize.height)
					frameBounds.height = deskSize.height;
				if (frameBounds.x + frameBounds.width > deskSize.width)
					frameBounds.x = deskSize.width - frameBounds.width;
				if (frameBounds.y + frameBounds.height > deskSize.height)
					frameBounds.y = deskSize.height - frameBounds.height;
				corrente.setBounds(frameBounds);
			}

		}
		repaintIconifiedFrames(desk);
	}

	/**
	 * Apre un frame della classe specificata utilizzando la visualizzazione a
	 * cascata. Se &egrave; gi&agrave; presente un frame della classe fornita, il frame viene
	 * attivato.
	 * 
	 * @param Class classe - un tipo di classe che estende JInternalFrame.
	 * @param javax.swing.JDesktopPane desk - un desktop pane.
	 * @throws IllegalArgumentException - la classe fornita non &egrave; un
	 *             JInternalFrame.
	 */
	public void openFrame(Class classe, JDesktopPane desk)
			throws IllegalArgumentException
	{
		if (classe.getSuperclass() != JInternalFrame.class)
			throw new IllegalArgumentException(
					"La classe fornita in input non ha"
							+ " come superclasse javax.swing.JInternalFrame.");
		try
		{
			JInternalFrame[] frames = desk.getAllFrames();
			int i;
			for (i = 0; i < frames.length; i++)
				if (frames[i].getClass().equals(classe))
					break;
			if (i == frames.length)
			{
				JInternalFrame nuovo = (JInternalFrame) classe.newInstance();
				desk.add(nuovo, Integer.MAX_VALUE);
				Dimension frameSize = nuovo.getPreferredSize();
				nuovo.setSize(frameSize);
				Dimension deskSize = desk.getSize();
				Point posNuovo = new Point(10, 10);
				for (i = frames.length - 1; i >= 0; i--)
				{
					if (frames[i].getLocation().equals(posNuovo))
					{
						posNuovo.x = frames[i].getLocation().x + 30;
						posNuovo.y = frames[i].getLocation().y + 30;
					}
				}
				if ((posNuovo.x + frameSize.width > deskSize.width)
						|| (posNuovo.y + frameSize.height > deskSize.height))
					centerFrame(nuovo);
				else
					nuovo.setLocation(posNuovo);
				nuovo.setVisible(true);
			}
			else
			{
				activateFrame(frames[i]);

			}
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}

	/**
	 * Visualizza un popup menu con opzioni relativi ai frame di un desktop pane
	 * nel punto selezionato.
	 * 
	 * @param java.awt.Point aPoint - il punto dove collocare il menu.
	 * @param javax.swing.JDesktopPane desk - un JDesktopPane cui &grave; associato un
	 *            istanza di DeskManager.
	 * @throws IllegalArgumentException - &grave; stato fornito come parametro un
	 *             JDesktopPane a cui non &grave; associato un Desk Manager.
	 */
	public void showPopupMenu(Point aPoint, JDesktopPane desk)
	{
		if (desk.getDesktopManager() != this)
			throw new IllegalArgumentException(
					"Non � stato trovato nessun oggetto"
							+ "di tipo DeskManager associato!");
		ripristinaTutti.setEnabled(true);
		chiudiTutti.setEnabled(true);
		riduciTutti.setEnabled(true);
		JInternalFrame[] frames = desk.getAllFrames();
		if (frames.length == 0)
		{
			ripristinaTutti.setEnabled(false);
			chiudiTutti.setEnabled(false);
			riduciTutti.setEnabled(false);
		}
		if (iconifiedFrames.size() == 0)
		{
			ripristinaTutti.setEnabled(false);

		}
		if (iconifiedFrames.size() == frames.length)
		{
			riduciTutti.setEnabled(false);
		}
		deskMenu.show(desk, aPoint.x, aPoint.y);
	}

	/**
	 * Deiconifica tutti i frames precedentemente iconificati.
	 *
	 */
	public void deiconifyAll()
	{
		if (iconifiedFrames.size() != 0)
		{
			Vector<JInternalFrame> copia = (Vector<JInternalFrame>) iconifiedFrames
					.clone();
			Iterator<JInternalFrame> frames = copia.iterator();
			while (frames.hasNext())
			{
				try
				{
					frames.next().setIcon(false);
				}
				catch (PropertyVetoException e)
				{
					e.printStackTrace();
				}

			}
			copia = null;
			iconifiedFrames.removeAllElements();

		}
	}

	/**
	 * Iconifica tutti i frame di un JDesktopPane fornito cui &grave; associato un
	 * DeskManager.
	 * 
	 * @param JDesktopPane desk - un desktop pane.
	 * @throws IllegalArgumentException - &grave; stato fornito come parametro un
	 *             JDesktopPane a cui non &grave; associato un Desk Manager.
	 */
	public void iconifyAll(JDesktopPane desk)
	{
		if (desk.getDesktopManager() != this)
			throw new IllegalArgumentException(
					"Non � stato trovato nessun oggetto"
							+ "di tipo DeskManager associato!");
		JInternalFrame[] frames = desk.getAllFrames();
		for (int i = 0; i < frames.length; i++)
			try
			{
				frames[i].setIcon(true);
			}
			catch (PropertyVetoException e)
			{
				e.printStackTrace();
			}
	}

	/**
	 * Chiude tutti i frame presenti in un dato JDesktopPane.
	 * 
	 * @param javax.swing.JDesktopPane desk - un desktop pane cui &grave; associato un
	 *            DeskManager.
	 * @throws IllegalArgumentException - &grave; stato fornito come parametro un
	 *             JDesktopPane a cui non &grave; associato un Desk Manager.
	 */
	public void closeAll(JDesktopPane desk)
	{
		if (desk.getDesktopManager() != this)
			throw new IllegalArgumentException(
					"Non � stato trovato nessun oggetto"
							+ "di tipo DeskManager associato!");
		JInternalFrame[] frames = desk.getAllFrames();
		if (frames.length != 0)
		{
			for (int i = 0; i < frames.length; i++)
				frames[i].dispose();
			iconifiedFrames.removeAllElements();
		}
	}

	/**
	 * Inizializza il DeskMenu.
	 * 
	 */
	public void initializeDeskMenu()
	{
		deskMenu = new JPopupMenu();
		riduciTutti = new JMenuItem("Riduci tutti a icona");
		riduciTutti.setIcon(new ImageIcon(getClass().getResource(
				URL_IMAGES + "reduceAll.png")));
		ripristinaTutti = new JMenuItem("Ripristina tutti");
		ripristinaTutti.setIcon(new ImageIcon(getClass().getResource(
				URL_IMAGES + "activateall.png")));
		chiudiTutti = new JMenuItem("Chiudi tutti");
		chiudiTutti.setIcon(new ImageIcon(getClass().getResource(
				URL_IMAGES + "closeall.png")));
		deskMenu.add(riduciTutti);
		deskMenu.addSeparator();
		deskMenu.add(ripristinaTutti);
		deskMenu.addSeparator();
		deskMenu.add(chiudiTutti);
		ActionListener menuListener = new ActionListener()
		{
			public void actionPerformed(ActionEvent aEvent)
			{
				if (aEvent.getSource() == ripristinaTutti)
					deiconifyAll();
				if (aEvent.getSource() == chiudiTutti)
					closeAll((JDesktopPane) deskMenu.getInvoker());
				if (aEvent.getSource() == riduciTutti)
					iconifyAll((JDesktopPane) deskMenu.getInvoker());
			}

		};
		riduciTutti.addActionListener(menuListener);
		ripristinaTutti.addActionListener(menuListener);
		chiudiTutti.addActionListener(menuListener);
	}
}
