/*
 * FeedbackTableModel.java
 *
 * 1.0
 *
 * 21/05/2007
 *
 * � 2007 eTour Project - Copyright by SE@SA Lab - DMI � University of Salerno
 */
package unisa.gps.etour.gui.operatoreagenzia.tables;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;

import javax.swing.table.*;

import unisa.gps.etour.bean.BeanVisitaBC;
import unisa.gps.etour.bean.BeanVisitaPR;



/**
 * <b>FeedbackTableModel</b>
 * <p>E' il modello contenitore dei dati relativi ai feedback ricevuti
 * da un bene culturale o da un punto di ristoro.</p>
 * 
 * @see javax.swing.table.AbstractTableModel
 * @see unisa.gps.etour.bean.BeanVisitaBC
 * @see unisa.gps.etour.bean.BeanVisitaPR
 * @version 1.0
 * @author Mario Gallo
 * 
 */
public class FeedBackTableModel extends AbstractTableModel
{
	
	private static final long serialVersionUID = 1L;
	private static final String[] headers = { "Voto", "Commento",
			"Data di Rilascio", "Rilasciato da" };
	private static final Class[] columnClasses = { Integer.class, String.class,
			Date.class, String.class };
	private ArrayList<Object[]> data;
	

	/**
	 * Costruttore di default. Si limita a creare il modello ma non
	 * carica nessun dato al suo interno.
	 * 
	 */
	public FeedBackTableModel()
	{
		data = new ArrayList<Object[]>();
	}

	/**
	 * Costruttore che prende in input un arraylist di BeanVisitaBC o 
	 * di BeanVisitaPR e ne copia i dati all'interno del modello 
	 * predisponendoli per la visualizzazione.
	 * 
	 * @param pVisite java.util.ArrayList - l'arraylist di bean.
	 */
	public FeedBackTableModel(HashMap <?,String> pDatiFeedback)
	{
		this();
		if (pDatiFeedback == null || pDatiFeedback.size() == 0)
		{
			return;
		}
		Iterator<?> itera = pDatiFeedback.keySet().iterator();
		while (itera.hasNext())
		{
			Object corrente = itera.next();
			if (corrente instanceof BeanVisitaBC)
			{
				insertVisitaBC((BeanVisitaBC)corrente, pDatiFeedback.get(corrente));
			}
			else if (corrente instanceof BeanVisitaPR)
			{
				insertVisitaPR((BeanVisitaPR)corrente, pDatiFeedback.get(corrente));
			}
		}
	}

	/**
	 * Restituisce il numero di colonne previste dal modello.
	 * 
	 * @return int - il numero di colonne.
	 * 
	 */
	public int getColumnCount()
	{
		return headers.length;
	}

	/**
	 * Restituisce il numero di righe attualmente presenti nel modello.
	 * 
	 * @return int - il numero di righe.
	 * 
	 */
	public int getRowCount()
	{
		return data.size();
	}

	
	/**
	 * Restituisce il nome della colonna dall'indice fornito.
	 * 
	 * @return String - il nome della colonna.
	 * @exception IllegalArgumentException - se l'indice di colonna fornito non �
	 * presente nel modello.
	 *  
	 */
	public String getColumnName(int pColumn) throws IllegalArgumentException
	{
		if (pColumn >= getColumnCount() || pColumn < 0)
		{
			throw new IllegalArgumentException(
					"L'indice di colonna fornito non � presente nel modello.");
		}
		return headers[pColumn];
	}

	/**
	 * Restituisce l'oggetto presente nel modello alla riga e alla colonna fornita.
	 * 
	 * @param pRow - il numero di riga.
	 * @param pColumn - il numero di colonna.
	 * @return Object - l'oggetto contenuto nella cella selezionata.
	 * @exception IllegalArgumentException - se l'indice o di riga o di colonna forniti non
	 * sono presenti nel modello.
	 * 
	 */
	public Object getValueAt(int pRow, int pColumn) throws IllegalArgumentException
	{
		if (pRow >= getRowCount() || pRow < 0) 
		{
			throw new IllegalArgumentException("L'indice di riga fornito non � presente nel modello.");
		}
		if (pColumn >= getColumnCount() || pColumn < 0) 
		{
			throw new IllegalArgumentException("L'indice di colonna fornito non � presente nel modello.");
		}
		return data.get(pRow)[pColumn];
	}

	/**
	 * Restituisce la classe degli oggetti contenuti nella colonna della quale viene fornito l'indice.
	 * 
	 * @param pColumn - il numero di colonna.
	 * @return Class - la classe degli oggetti della colonna selezionata.
	 * @exception IllegalArgumentException - se l'indice di colonna fornito non � presente
	 * nel modello.
	 * 
	 */
	public Class getColumnClass(int pColumn) throws IllegalArgumentException
	{
		if (pColumn >= getColumnCount() || pColumn < 0) 
		{
			throw new IllegalArgumentException("L'indice di colonna fornito non � presente nel modello.");
		}
		return columnClasses[pColumn];
	}

	/**
	 * Restituisce se la cella selezionata � editabile.
	 * 
	 * @return boolean - true se la cella � editabile
	 * 					 false altrimenti
	 * @param pRow - il numero di riga.
	 * @param pColumn - il numero di colonna.
	 * @exception IllegalArgumentException - se l'indice o di riga o di colonna forniti non sono
	 * presenti nel modello.
	 * 
	 */
	public boolean isCellEditable(int pRow, int pColumn) throws IllegalArgumentException
	{
		return false;
	}
	
	/**
	 * Il metodo setValueAt ereditato dall'interfaccia TableModel non � necessario alla SitoTableModel
	 * in quanto non � prevista la possibilit� di modificare una singola cella. 
	 * @deprecated
	 * 
	*/
	public void setValueAt(Object value, int row, int col) 
	{
		
	}
	
	/**
	 * 
	 * Inserisce i dati relativi al feedback ricevuto da un bene culturale 
	 * nel modello a partire dal Bean.
	 *
	 * @param pBC BeanVisitaBC - il bean contenente il feedback ricevuto dal
	 * bene culturale.
	 * @throws IllegalArgumentException - se i parametri forniti in input non
	 * sono validi.
	 * 
	 */
	public void insertVisitaBC (BeanVisitaBC pVisitaBC, String pUsername) throws IllegalArgumentException
	{
		if (pVisitaBC == null || pUsername == null || pUsername.equals(""))
		{
			throw new IllegalArgumentException("Parametri forniti in input non validi.");
		}
		Object[] aRow = new Object[6];
		aRow[0] = pVisitaBC.getVoto();
		aRow[1] = pVisitaBC.getCommento();
		aRow[2] = pVisitaBC.getDataVisita();
		aRow[3] = pUsername;
		aRow[4] = pVisitaBC.getIdBeneCulturale();
		aRow[5] = pVisitaBC.getIdTurista();
		data.add(aRow);
	}
	
	/**
	 * 
	 * Inserisce i dati relativi al feedback ricevuto da un punto di ristoro 
	 * nel modello a partire dal Bean.
	 *
	 * @param pBC BeanVisitaPR - il bean contenente il feedback ricevuto dal
	 * punto di ristoro.
	 * @throws IllegalArgumentException - se i parametri forniti in input non
	 * sono validi.
	 * 
	 */
	public void insertVisitaPR (BeanVisitaPR pVisitaPR, String pUsername) throws IllegalArgumentException
	{
		if (pVisitaPR == null || pUsername == null || pUsername.equals(""))
		{
			throw new IllegalArgumentException("Parametri forniti in input non validi.");
		}
		Object[] aRow = new Object[6];
		aRow[0] = pVisitaPR.getVoto();
		aRow[1] = pVisitaPR.getCommento();
		aRow[2] = pVisitaPR.getDataVisita();
		aRow[3] = pUsername;
		aRow[4] = pVisitaPR.getIdPuntoDiRistoro();
		aRow[5] = pVisitaPR.getIdTurista();
		data.add(aRow);
	}
	/**
	 * 
	 * Aggiorna il commento di un feedback contenuto nella table alla riga selezionata.
	 *
	 * @param pNuovoCommento String - il nuovo commento.
	 * @param pRow - la riga da aggiornare.
	 * @throws IllegalArgumentException - se <ul><li>l'indice di riga non è presente nel modello.
	 * <li>il nuovo commento fornito in input è nullo.</ul>
	 */
	public void modificaCommento(String pNuovoCommento, int pRow) throws IllegalArgumentException
	{
		if (pRow >= getRowCount() || pRow < 0) 
		{
			throw new IllegalArgumentException("L'indice di riga fornito non � presente nel modello.");
		}
		if (pNuovoCommento == null)
		{
			throw new IllegalArgumentException("Il nuovo commento non può essere nullo.");
		}
		data.get(pRow)[1] = pNuovoCommento;
		fireTableDataChanged();
	}
	
	/**
	 * 
	 * Restituisce l'id del feedback ricevuto visualizzato alla riga fornita in input.
	 *
	 * @param pRow int - il numero di riga.
	 * @return int[]  - gli id del feedback.
	 * @throws IllegalArgumentException - se l'indice di riga fornito non � presente
	 * nel modello.
	 */
	public int[] getIDFeedback(int pRow) throws IllegalArgumentException
	{
		if (pRow >= getRowCount() || pRow < 0) 
		{
			throw new IllegalArgumentException("L'indice di riga fornito non � presente nel modello.");
		}
		int[] ids = new int[2];
		ids[0] = (Integer) data.get(pRow)[4];
		ids[1] = (Integer) data.get(pRow)[5];
		return ids;
	}
	
	/**
	 * 
	 * Restituisce l'id del feedback al numero di riga fornito in input e lo rimuove dal modello.
	 *
	 * @param pRow int - il numero di riga.
	 * @return int[] - gli id del feedback.
	 * @exception IllegalArgumentException - se l'indice di riga fornito non � presente
	 * nel modello.
	 * 
	 */
	public int[] removeFeedback(int pRow) throws IllegalArgumentException
	{
		int[] ids = getIDFeedback(pRow);
		data.remove(pRow);
		return ids;
	}
}
