/**
 * Implementazione dell'interfaccia di gestione dell'advertisement
 * per l'operatore agenzia. Contiene i metodi di gestione delle 
 * news.
 *
 * @author Palladino Fabio
 * @version 0.1
 * 
 * � 2007 eTour Project - Copyright by SE@SA Lab DMI � University of Salerno
 */
package unisa.gps.etour.control.GestioneAdvertisement;

import java.rmi.RemoteException;
import java.sql.SQLException;
import java.util.ArrayList;

import unisa.gps.etour.bean.BeanNews;
/* importazione dello stub */ 
//import unisa.gps.etour.control.GestioneAdvertisement.test.stubs.DBNews;
import unisa.gps.etour.repository.DBNews;
import unisa.gps.etour.repository.IDBNews;
import unisa.gps.etour.util.ControlloDati;
import unisa.gps.etour.util.CostantiGlobali;
import unisa.gps.etour.util.MessaggiErrore;


public class GestioneAdvertisementAgenzia extends GestioneAdvertisement
		implements IGestioneAdvertisementAgenzia
{
	private static final long serialVersionUID = 1L;
	/** contiene i metodi per gestione delle news nel database */
	private IDBNews dbNews;
	
	/**
	 * Costruttore. Istanzia un oggetto di tipo {@link unisa.gps.etour.repository.DBNews}.
	 * 
	 * @throws RemoteException
	 */
	public GestioneAdvertisementAgenzia() throws RemoteException
	{
		super();
		dbNews = new DBNews();
	}
	
	/**
	 * Metodo che cancella una news dal database. Utilizza il metodo
	 * {@link boolean unisa.gps.etour.repository.IDBNews#cancellaNews(int)}
	 * 
	 * @param pNewsID id della news da cancellare.
	 * @return true se la cancellazione è andata a buon fine false altrimenti.
	 * @throws RemoteException
	 * 
	 */
	public boolean cancellaNews(int pNewsID) throws RemoteException
	{
		
		try 
		{
			/* controlla che l'id sia valido */
			if(pNewsID > 0){
				return (dbNews.cancellaNews(pNewsID));
			}else{
				return false;
			}		
		} catch (SQLException e) {
			throw new RemoteException(MessaggiErrore.ERRORE_CONNESSIONE_DBMS);
		}
	}	
	
	/**
	 * Inserisce una nuova news nel database.
	 * Utilizza il metodo {@link  unisa.gps.etour.repository.IDBNews#inserisciNews(BeanNews)}
	 * per  inserire la news e il metodo {@link  unisa.gps.etour.repository.IDBNews#ottieniNews()}
	 * per contare il numero di news presenti nel sistema.
	 *
	 * @param pNews bean contenente i dati della news.
	 * @return true se l'inserimento va a buon fine, false se è stato 
	 * raggiunto il numero massimo di news memorizzabili o se l'inserimento non ha successo.
	 * @throws RemoteException
	 */
	public boolean inserisciNews(BeanNews pNews) throws RemoteException
	{
		try 
		{
			/* controlla i dati della news */
			if (!ControlloDati.checkBeanNews(pNews)){
				throw new RemoteException(MessaggiErrore.ERRORE_DATI);
			}
			/* controlla che non sia stato superato il num. max di news memorizzabili */
			int numNews = dbNews.ottieniNews().size();
			if(numNews < CostantiGlobali.MAX_NEWS_ATTIVE){
				/* inserimento possibile */
				return (dbNews.inserisciNews(pNews));
			}else{
				/* inserimento non possibile */
				return false;
			}		
		} catch (SQLException e) {
			throw new RemoteException(MessaggiErrore.ERRORE_CONNESSIONE_DBMS);
		}
	}
	
	/**
	 * Metodo che modifica i dati di una news.
	 * Utilizza il metodo {@link unisa.gps.etour.repository.IDBNews#modificaNews(BeanNews)}.
	 * 
	 * @param pNews bean contenente i dati della news modificata.
	 * @return true se la modifica va a buon fine.
	 * @throws RemoteException 
	 */
	public boolean modificaNews(BeanNews pNews) throws RemoteException
	{
		
		try 
		{
			/* controlla i dati della news */
			if (!ControlloDati.checkBeanNews(pNews)){
				throw new RemoteException(MessaggiErrore.ERRORE_DATI);
			}
			return (dbNews.modificaNews(pNews));		
		} catch (SQLException e) {
			throw new RemoteException(MessaggiErrore.ERRORE_CONNESSIONE_DBMS);
		}		
	}
	
	/**
	 * Metodo che restituisce un array contenente tutte le news memorizzate nel sistema.
	 * Utilizza il metodo {@link unisa.gps.etour.repository.IDBNews#ottieniNews()}.
	 * 
	 * @return ArrayList contenente i bean delle news.
	 * @throws RemoteException  
	 */
	public ArrayList<BeanNews> ottieniAllNews() throws RemoteException
	{
		
		try 
		{			
			return (dbNews.ottieniNews());		
		} catch (SQLException e) {
			throw new RemoteException(MessaggiErrore.ERRORE_CONNESSIONE_DBMS);
		}
	}
}
