package unisa.gps.etour.control.GestioneBeniCulturali;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import unisa.gps.etour.bean.BeanBeneCulturale;
import unisa.gps.etour.bean.BeanTag;
import unisa.gps.etour.bean.BeanVisitaBC;
import unisa.gps.etour.repository.DBTag;
//import unisa.gps.etour.repository.DBBeneCulturale;
//import unisa.gps.etour.repository.DBTurista;
//import unisa.gps.etour.repository.DBVisitaBC;
import unisa.gps.etour.repository.IDBBeneCulturale;
import unisa.gps.etour.repository.IDBTag;
import unisa.gps.etour.repository.IDBTurista;
import unisa.gps.etour.repository.IDBVisitaBC;
import unisa.gps.etour.util.CostantiGlobali;
import unisa.gps.etour.util.MessaggiErrore;

// Stub
import unisa.gps.etour.control.GestioneBeniCulturali.test.stub.DBBeneCulturale; // ***
import unisa.gps.etour.control.GestioneBeniCulturali.test.stub.DBTurista; // ***
import unisa.gps.etour.control.GestioneBeniCulturali.test.stub.DBVisitaBC; // ***

/**
 * Classe di gestione di beni culturali per le operazioni comuni a tutti gli attori
 *
 * @author De Simone Michelangelo
 * @version 0.1
 * 
 *  &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI - University of Salerno
 */
/**
 *
 */
public class GestioneBeniCulturaliComune extends UnicastRemoteObject implements
		IGestioneBeniCulturaliComune 
{
	// Connessione al DB per i Beni Culturali
	protected IDBBeneCulturale dbbc;
	
	// Connessione al DB per i Tag
	protected IDBTag dbtag;
	
	// Connessione al DB per i Feedback/Visite
	protected IDBVisitaBC dbvisita;
	
	// Connessione al DB per i Turisti
	protected IDBTurista dbturista;
	
	/**
 	 * Costruttore; si istanziano tutti i campi utili alla gestione dei dati;
	 * i campi vengono inizializzati ad ogni istanza di classe.
	 * 
	 * @throws RemoteException Eccezione nel flusso
	 */
	public GestioneBeniCulturaliComune() throws RemoteException
	{
		// Supercostruttore della classe UnicastRemoteObject
		super();
		
		// Si istanziano gli oggetti
		try
		{
			dbbc = new DBBeneCulturale();
			dbtag = new DBTag();
			dbvisita = new DBVisitaBC();
			dbturista = new DBTurista();
		}
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
	}

	/*
	 * Implementa il metodo per l'ottenimento di un bene culturale tramite Id.
	 * 
	 * @see unisa.gps.etour.control.GestioneBeniCulturali.IGestioneBeniCulturaliComune#ottieniBeneCulturale(int)
	 */
	public BeanBeneCulturale ottieniBeneCulturale(int pBeneCulturaleID)	throws RemoteException
	{
		if (!ControlloBeniCulturali.controllaIdBeneCulturale(pBeneCulturaleID))
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		
		BeanBeneCulturale bbc = null;
		
		try
		{
			bbc = dbbc.ottieniBeneCulturale(pBeneCulturaleID);			
		}
		catch (SQLException e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		
		return bbc;
	}

	/*
	 * Implementa il metodo per l'ottenimento di tutti i tag di un bene culturale.
	 * 
	 * @see unisa.gps.etour.control.GestioneBeniCulturali.IGestioneBeniCulturaliComune#ottieniTagBeneCulturale(int)
	 */
	public ArrayList<BeanTag> ottieniTagBeneCulturale(int pBeneCulturaleID) throws RemoteException
	{
		if (!ControlloBeniCulturali.controllaIdBeneCulturale(pBeneCulturaleID))
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		
		ArrayList<BeanTag> btag = null;
		
		try
		{
			btag = dbtag.ottieniTagBeneCulturale(pBeneCulturaleID);
		}
		catch (SQLException e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		
		return btag;
	}

	/*
	 * Implementa il metodo per ottenere la lista dei feedback e dei relativi username su un bene
	 * culturale specificato tramite Id.
	 * 
	 * @see unisa.gps.etour.control.GestioneBeniCulturali.IGestioneBeniCulturaliComune#ottieniFeedbackBeneCulturale(int)
	 */
	public HashMap<BeanVisitaBC, String> ottieniFeedbackBeneCulturale(int pBeneCulturaleID) throws RemoteException
	{
		if (!ControlloBeniCulturali.controllaIdBeneCulturale(pBeneCulturaleID))
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		
		HashMap<BeanVisitaBC, String> mappaRitorno;
		
		try
		{
			// Istanzio la mappa delle stesse dimensioni della lista di BeanVisitaBC			
			mappaRitorno = new HashMap<BeanVisitaBC, String>(dbvisita.ottieniListaVisitaBC(pBeneCulturaleID).size());

			// Per ogni visita aggiungo il relativo username
			// Qui inizio a iterare per aggiungere a ogni visita il relativo username
			for (BeanVisitaBC b: dbvisita.ottieniListaVisitaBC(pBeneCulturaleID))
				mappaRitorno.put(b, dbturista.ottieniTurista(b.getIdTurista()).getUsername());

		}
		catch (SQLException e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		
		return mappaRitorno;
	}
	
	/*
	 * Implementa il metodo per ottenere le statistiche su un bene culturale passato
	 * tramite Id.
	 *  
	 * @see unisa.gps.etour.control.GestioneBeniCulturali.IGestioneBeniCulturaliComune#ottieniStatisticheBeneCulturale(int)
	 */
	public ArrayList<Integer> ottieniStatisticheBeneCulturale(int pBeneCulturaleID) throws RemoteException
	{
		/*
		 * Questo metodo restituisce un ArrayList contenente 5 elementi (0..4).
		 * Ad ogni indice piu' uno corrisponde il numero di feedback di valore equivalente proprio
		 * al numero di indice piu' uno.
		 * Anche in questo caso il metodo non e' particolarmente attraente ma fa il suo sporco lavoro
		 * egregiamente.
		 */

		if (!ControlloBeniCulturali.controllaIdBeneCulturale(pBeneCulturaleID))
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);

		ArrayList<Integer> listaRisultati = new ArrayList<Integer>(5);

		// Imposta tutti gli indici a 0
		for (int i = 0; i < 5; i++)
			listaRisultati.add(i, Integer.valueOf(0));
		
		// Calcola la data per gli ultimi trenta giorni
		Date ultimiTrentaGiorni = new Date(new Date().getTime() - CostantiGlobali.TRENTA_GIORNI);
		
		try
		{
			// Ottiene tutte le visite di un certo bene culturale
			// Itera alla ricerca delle visite/feedback ottenuti entro gli ultimi trenta giorni
			for (BeanVisitaBC b: dbvisita.ottieniListaVisitaBC(pBeneCulturaleID))
				if (b.getDataVisita().after(ultimiTrentaGiorni))
					listaRisultati.set(b.getVoto() - 1,	Integer.valueOf(listaRisultati.get(b.getVoto() - 1).intValue() + 1));
		}
		catch (SQLException e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		
		return listaRisultati;
	}
	
	/*
	 * Implementa il metodo per la modifica di un feedback su un bene culturale passato
	 * tramite Id.
	 * 
	 * @see unisa.gps.etour.control.GestioneBeniCulturali.IGestioneBeniCulturaliComune#modificaFeedbackBeneCulturale(int, unisa.gps.etour.bean.BeanVisitaBC)
	 */
	public boolean modificaFeedbackBeneCulturale(int pBeneCulturaleID, BeanVisitaBC pBeanVisitaBC) throws RemoteException
	{
		if (!ControlloBeniCulturali.controllaIdBeneCulturale(pBeneCulturaleID) ||
			!ControlloVisiteBeniCulturali.controllaDatiVisitaBeneCulturale(pBeanVisitaBC))
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);

		/*
		 * Si controlla che il voto non sia cambiato.
		 * Se il voto viene cambiato viene lanciata un'eccezione
		 */
		boolean votoOk = true;
		
		try
		{
			votoOk =  dbvisita.ottieniVisitaBC(pBeneCulturaleID, pBeanVisitaBC.getIdTurista()).getVoto() == pBeanVisitaBC.getVoto();
		}
		catch (SQLException e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}

		/*
		 * Se il voto non è cambiato si procede all'invio del messaggio al metodo di
		 * modifica del layer database.
		 */
		if (votoOk)
			try
			{
				return (dbvisita.modificaVisitaBC(pBeanVisitaBC));
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}

		return false;
	}
}
