package unisa.gps.etour.control.GestionePuntiDiRistoro;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import unisa.gps.etour.bean.BeanPuntoDiRistoro;
import unisa.gps.etour.bean.BeanTag;
import unisa.gps.etour.bean.BeanVisitaPR;
/*
 * Per i test di junit import
 * unisa.gps.etour.control.GestionePuntiDiRistoro.test.stub.DBPuntoDiRistoro;
 * import unisa.gps.etour.control.GestionePuntiDiRistoro.test.stub.DBVisitaPR;
 */
import unisa.gps.etour.repository.DBPuntoDiRistoro;
import unisa.gps.etour.repository.DBVisitaPR;
import unisa.gps.etour.repository.DBTag;
import unisa.gps.etour.repository.IDBPuntoDiRistoro;
import unisa.gps.etour.repository.IDBTag;
import unisa.gps.etour.repository.IDBTurista;
import unisa.gps.etour.repository.IDBVisitaPR;
import unisa.gps.etour.util.CostantiGlobali;
import unisa.gps.etour.util.MessaggiErrore;

/**
 * Classe che implementa le operazioni comuni per l'Operatore Punto di Ristoro e
 * per l'Operatore Agenzia
 * 
 * @author Morelli Giuseppe
 * @version 0.1 &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *          University of Salerno
 */
public class GestionePuntiDiRistoroComune extends UnicastRemoteObject implements
		IGestionePuntiDiRistoroComune
{

	// Istanze per le connessioni al database
	private static final long serialVersionUID = 1L;
	protected IDBPuntoDiRistoro puntoRistoro;
	protected IDBTag tag;
	protected IDBVisitaPR feed;
	protected IDBTurista dbTurista;

	public GestionePuntiDiRistoroComune() throws RemoteException
	{
		super();
		// Connessione al Database
		try
		{
			puntoRistoro = new DBPuntoDiRistoro();
			tag = new DBTag();
			feed = new DBVisitaPR();
		}
		// ATTENZIONE: Non viene piu' generata SQLException causa
		// modifiche al layer DB; modificato in Exception
		catch (Exception e)
		{
			System.out.println("Errore:" + e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
	}

	/*
	 * Metodo che permette di ottenere un BeanPuntoDiRistoro tramite la
	 * connessione al database
	 */
	public BeanPuntoDiRistoro ottieniPuntoDiRistoro(int pPuntoDiRistoroID)
			throws RemoteException
	{
		// Controllo sull'identificativo passato
		if (pPuntoDiRistoroID < 0)
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		// Istanza di ritorno
		BeanPuntoDiRistoro toReturn = null;
		try
		{
			// Ricavo i dati attraverso l'istanza della connessione al database
			toReturn = puntoRistoro.ottieniPuntoDiRistoro(pPuntoDiRistoroID);
		}
		// Eccezione nelle operazioni sul Database
		catch (SQLException e)
		{
			System.out.println("Errore:" + e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezioni impreviste determinate da altri fattori
		catch (Exception ee)
		{
			System.out.println("Errore:" + ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		// Controllo la variabile di ritorno, in modo da non passare dati errati
		// al chiamante
		// e nel caso scatena un'eccezione sul formato del bean
		if (toReturn == null)
			throw new RemoteException(MessaggiErrore.ERRORE_FORMATO_BEAN);
		// Ritorno il bean contenente le informazioni sul Punto di Ristoro
		// richiesto
		return toReturn;
	}

	// Metodo che ritorna un ArrayList contenente i tag identificativi di un
	// certo Punto di Ristoro
	public ArrayList<BeanTag> ottieniTagPuntoDiRistoro(int pPuntoDiRistoroID)
			throws RemoteException
	{
		// Controllo sull'identificativo passato
		if (pPuntoDiRistoroID < 0)
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		// Istanza di ritorno
		ArrayList<BeanTag> toReturn = null;
		try
		{
			// Ricavo i dati attraverso l'istanza della connessione al database
			toReturn = tag.ottieniTagPuntoDiRistoro(pPuntoDiRistoroID);
		}
		// Eccezione nelle operazioni sul database
		catch (SQLException e)
		{
			System.out.println("Errore:" + e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezioni impreviste determinate da altri fattori
		catch (Exception ee)
		{
			System.out.println("Errore:" + ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		// Controllo la variabile di ritorno, in modo da non passare dati errati
		// al chiamante
		// e nel caso scatena un'eccezione sul formato del bean
		if (toReturn == null)
			throw new RemoteException(MessaggiErrore.ERRORE_FORMATO_BEAN);
		// Ritorno l'ArrayList contenente i bean dei tag del punto di ristoro
		// passato come parametro
		return toReturn;
	}

	// Restituisce un array di 10 stringhe contenenti gli ultimi 10 commenti
	// rilasciati dai Turisti per il Punto di Ristoro passato come parametro
	public String[] ottieniUltimiCommenti(int pPuntoDiRistoroID)
			throws RemoteException
	{
		// Controllo la validità dell'identificativo passato
		if (pPuntoDiRistoroID < 0)
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		// Stringa che conterrà solo gli ultimi 10 commenti rilasciati
		String[] toReturn = new String[10];
		// ArrayList temporaneo per salvare poi i commenti dei bean contenuti al
		// suo interno
		ArrayList<BeanVisitaPR> temp = null;
		try
		{
			// Cerco di recuperare le informazioni dal database tramite
			// l'istanza della connessione
			temp = feed.ottieniListaVisitaPR(pPuntoDiRistoroID);
		}
		// Eccezione nelle operazioni sul Database
		catch (SQLException e)
		{
			System.out.println("Errore nel metodo ottieniUltimiCommenti: "
					+ e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezioni impreviste determinate da altri fattori
		catch (Exception ee)
		{
			System.out.println("Errore nel metodo ottieniUltimiCommenti: "
					+ ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		// I bean che ricevo dal database sono già ordinati per data
		// implicitamente, quindi non c'è bisogno di algoritmi di ordinamento
		for (int i = 0; i < 10; i++)
		{
			// Inserisco ciclicamente il testo dei commenti all'interno
			// dell'array
			toReturn[i] = (temp.get(temp.size() - (i + 1))).getCommento();
		}
		// E' inutile un controllo sul formato dell'array
		// Quindi ritorno direttamente l'array con i commenti
		return toReturn;
	}

	// Metodo che restituisce un ArrayList contenente il numero di voti
	// rilasciati da 1 a 5 per
	// il Punto di Ristoro passato come parametro. Il metodo inserisce in ordine
	// i contatori nelle posizioni
	// a partire da 0 per il voto 1, 1 per il voto 2, etc..
	public ArrayList<Integer> ottieniStatistichePuntoDiRistoro(
			int pPuntoDiRistoroID) throws RemoteException
	{
		// Controllo la validità dell'identificativo passato
		if (pPuntoDiRistoroID < 0)
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		// ArrayList che mi permette di memorizzare i bean contenenti i feedback
		ArrayList<BeanVisitaPR> bVisita = null;
		// ArrayList che mi permette di memorizzare i contatori
		// e che poi ritornerò al metodo chiamante
		ArrayList<Integer> listaRisultati = new ArrayList<Integer>(5);
		// Inizializzazione dell'array di contatori
		for (int i = 0; i < 5; i++)
			listaRisultati.add(Integer.valueOf(0));
		// Data utile a verificare che i feedback rilasciati risalgano a trenta
		// giorni dalla data corrente
		Date ultimiTrentaGiorni = new Date(new Date().getTime()
				- CostantiGlobali.TRENTA_GIORNI);

		System.out.println("La data di 30 gg fa è : " + ultimiTrentaGiorni);

		try
		{
			// Ricavo tutti i feedback rilasciati per il Punto di Ristoro
			// passato come parametro
			bVisita = feed.ottieniListaVisitaPR(pPuntoDiRistoroID);
			// Itero la collezione di elementi per controllare i bean delle
			// visite
			for (Iterator<BeanVisitaPR> iteratoreVisitaPR = bVisita.iterator(); iteratoreVisitaPR
					.hasNext();)
			{
				// Recuperto il BeanVisitaPR
				BeanVisitaPR bVisitaTemp = iteratoreVisitaPR.next();
				// ...non si sa che fa...
				System.out.println("La data di questa visita è: "
						+ bVisitaTemp.getDataVisita());
				if (bVisitaTemp.getDataVisita().after(ultimiTrentaGiorni))
					listaRisultati.set(bVisitaTemp.getVoto() - 1, Integer
							.valueOf(listaRisultati.get(
									bVisitaTemp.getVoto() - 1).intValue() + 1));
			}
		}
		// Eccezione nelle operazioni sul Database
		catch (SQLException e)
		{
			System.out
					.println("Errore nel metodo ottieniStatistichePuntoDiRistoro: "
							+ e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezioni impreviste determinate da altri fattori
		catch (Exception ee)
		{
			System.out
					.println("Errore nel metodo ottieniStatistichePuntoDiRistoro: "
							+ ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		if (listaRisultati == null)
			throw new RemoteException(MessaggiErrore.ERRORE_FORMATO_BEAN);
		// Ritorno la lista dei risultati che dovrebbe contenere i contatori dei
		// commenti
		// rilasciati negli ultimi 30 gg
		return listaRisultati;
	}

	// Metodo che permette di modificare il commento rilasciato per un certo
	// Punto di Ristoro
	public boolean modificaFeedbackPuntoDiRistoro(int pPuntoDiRistoroId,
			BeanVisitaPR nuovaVisita) throws RemoteException
	{
		// Controllo la validità dei dati passati
		if ((pPuntoDiRistoroId < 0) || (!(nuovaVisita instanceof BeanVisitaPR)))
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		// Ricavo dal database il bean precedentemente salvato e lo memorizzo
		// in modo da verificare che non sia stato modificato il voto
		// che era stato rilasciato in precedenza
		BeanVisitaPR temp = null;
		try
		{
			temp = feed.ottieniVisitaPR(pPuntoDiRistoroId, nuovaVisita
					.getIdTurista());
		}
		// Eccezione nell'esecuzione dell'operazione sul Database
		catch (SQLException e)
		{
			System.out
					.println("Errore nel metodo modificaFeedbackPuntoDiRistoro: "
							+ e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezione imprevista causata da altri fattori
		catch (Exception ee)
		{
			System.out
					.println("Errore nel metodo modificaFeedbackPuntoDiRistoro: "
							+ ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		// Se il voto è stato modificato restituisco una eccezione
		if (temp.getVoto() != nuovaVisita.getVoto())
			throw new RemoteException(MessaggiErrore.ERRORE_FORMATO_BEAN);
		// Se il voto non è stato modificato provvedo a salvare il nuovo
		// commento nel database tramite l'apposito metodo del bean
		else
		{
			try
			{
				feed.modificaVisitaPR(nuovaVisita);
				return true;
			}
			// Eccezione nell'esecuzione dell'operazione sul Database
			catch (SQLException e)
			{
				System.out
						.println("Errore nel metodo modificaFeedbackPuntoDiRistoro: "
								+ e.toString());
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			// Eccezione imprevista causata da altri fattori
			catch (Exception ee)
			{
				System.out
						.println("Errore nel metodo modificaFeedbackPuntoDiRistoro: "
								+ ee.toString());
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
	}
}
