﻿package unisa.gps.etour.control.GestioneUtentiRegistrati;

import java.rmi.RemoteException;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Iterator;

import unisa.gps.etour.bean.BeanBeneCulturale;
import unisa.gps.etour.bean.BeanPreferenzaDiRicerca;
import unisa.gps.etour.bean.BeanPreferenzeGeneriche;
import unisa.gps.etour.bean.BeanPuntoDiRistoro;
import unisa.gps.etour.bean.BeanTurista;
import unisa.gps.etour.bean.BeanVisitaBC;
import unisa.gps.etour.bean.BeanVisitaPR;
import unisa.gps.etour.repository.DBBeneCulturale;
import unisa.gps.etour.repository.DBPreferenzeDiRicerca;
import unisa.gps.etour.repository.DBPreferenzeGeneriche;
import unisa.gps.etour.repository.DBPuntoDiRistoro;
import unisa.gps.etour.repository.DBTurista;
import unisa.gps.etour.repository.DBVisitaBC;
import unisa.gps.etour.repository.DBVisitaPR;
import unisa.gps.etour.repository.IDBBeneCulturale;
import unisa.gps.etour.repository.IDBPreferenzeDiRicerca;
import unisa.gps.etour.repository.IDBPreferenzeGeneriche;
import unisa.gps.etour.repository.IDBPuntoDiRistoro;
import unisa.gps.etour.repository.IDBTurista;
import unisa.gps.etour.repository.IDBVisitaBC;
import unisa.gps.etour.repository.IDBVisitaPR;
import unisa.gps.etour.util.ControlloDati;
import unisa.gps.etour.util.MessaggiErrore;

/**
 * Classe relativa alla gestione dei Dati del Turista
 * 
 * @author Leone Federico
 * @version 0.1 2007 eTour Project - Copyright by SE@SA Lab DMI University of
 *          Salerno
 */

public class GestioneTuristaClient extends GestioneTuristaComune implements
		IGestioneTuristaClient
{
	private static final long serialVersionUID = -6161592850721537385L;
	private IDBTurista profiloTurista;				//Gestione dati relativi al turista
	private IDBPreferenzeGeneriche prefGenTurista;			//Gestione preferenze generiche del turista
	private IDBPreferenzeDiRicerca prefRicTurista;			//Gestione preferenze di ricerca del turista
	private IDBVisitaBC visitatiBC;					//Gestione beni culturali visitati
	private IDBVisitaPR visitatiPR;					//Gestione punti di ristoro visitati
	private IDBBeneCulturale beneCulturale;				//Gestione beni culturali (ci serve unicamente x ottenere un bean BeneCulturale
									//a partire dal suo ID
	private IDBPuntoDiRistoro puntoDiRistoro;			//Gestione punti di ristoro (utilizzo identico all'oggetto "beneCulturale"

	public GestioneTuristaClient() throws RemoteException
	{
		super();

		profiloTurista = new DBTurista();
		prefGenTurista = new DBPreferenzeGeneriche();
		prefRicTurista = new DBPreferenzeDiRicerca();
		visitatiBC = new DBVisitaBC();
		visitatiPR = new DBVisitaPR();
		beneCulturale = new DBBeneCulturale();
		puntoDiRistoro = new DBPuntoDiRistoro();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#cancellaPreferenzeDiRicerca(int,
	 *      int)
	 */
	public BeanPreferenzaDiRicerca cancellaPreferenzeDiRicerca(int pIdTurista,int pIdPreferenzaDiRicerca) throws RemoteException
	{
		try
		{
			boolean cancellazione = true;
			BeanPreferenzaDiRicerca PrefRic = new BeanPreferenzaDiRicerca();
			ArrayList<BeanPreferenzaDiRicerca> ElencoPrefRic = new ArrayList<BeanPreferenzaDiRicerca>();

			ElencoPrefRic = prefRicTurista.ottieniPreferenzeDiRicercaDelTurista(pIdTurista);
			Iterator<BeanPreferenzaDiRicerca> elenco = ElencoPrefRic.iterator();

			while (elenco.hasNext() && cancellazione == true)
			{
				PrefRic = elenco.next();
				if (PrefRic.getId() == pIdPreferenzaDiRicerca)
					cancellazione = false; // Trovata la ricorrenza con l'id
				// che ci interessa usciamo dal
				// ciclo
			}

			cancellazione = prefRicTurista.cancellaPreferenzaDiRicercaTurista(
					pIdTurista, pIdPreferenzaDiRicerca);
			return PrefRic;
		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#cancellaPreferenzeGeneriche(int)
	 */
	public BeanPreferenzeGeneriche cancellaPreferenzeGeneriche(int pIdTurista) throws RemoteException
	{
		try
		{
			BeanPreferenzeGeneriche temp = prefGenTurista.ottieniPreferenzaGenerica(pIdTurista);
			boolean cancellazione = prefGenTurista.cancellaPreferenzaGenerica(temp.getId());

			if (cancellazione)
				return temp;
			else
				return null; // La cancellazione non è avvenuta
		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciPreferenzaDiRicerca(int,
	 *      unisa.gps.etour.bean.BeanPreferenzaDiRicerca)
	 */
	public boolean inserisciPreferenzaDiRicerca(int pIdTurista,BeanPreferenzaDiRicerca pPreferenzaDiRicerca) throws RemoteException
	{
		try
		{
			boolean checkDati = ControlloDati.checkBeanPreferenzaDiRicerca(pPreferenzaDiRicerca);

			if (checkDati)
			{ // Se il controllo dei dati è positivo
				return prefRicTurista.inserisciPreferenzaDiRicercaDelTurista(pIdTurista, pPreferenzaDiRicerca.getId());
			}
			else
			{
				return false; // Errore nei dati
			}

		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciPreferenzeGeneriche(unisa.gps.etour.bean.BeanPreferenzeGeneriche)
	 */
	public boolean inserisciPreferenzeGeneriche(BeanPreferenzeGeneriche pPreferenzeGeneriche) throws RemoteException
	{
		try
		{
			boolean checkDati = ControlloDati.checkBeanPreferenzeGeneriche(pPreferenzeGeneriche);

			if (checkDati)
			{ // Se il controllo dei dati è positivo
				return prefGenTurista.inserisciPreferenzaGenenerica(pPreferenzeGeneriche);
			}
			else
			{
				return false; // Errore nei dati
			}

		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciTurista(unisa.gps.etour.bean.BeanTurista)
	 */
	public boolean inserisciTurista(BeanTurista pTurista) throws RemoteException
	{
		try
		{
			
			//Controllo se l'username inserito è già presente nel DB
			BeanTurista temp = profiloTurista.ottieniTurista(pTurista.getUsername());
			
			//Se non esiste un turista associato all'username scelta
			if (temp == null)
			{
				boolean checkDati = ControlloDati.checkBeanTurista(pTurista);

				if (checkDati)
				{ // Se il controllo dei dati è positivo
					return profiloTurista.inserisciTurista(pTurista);
				}
				else
				{
					return false; // Errore nei dati
				}
			}
			else
			{
				return false; //Username già presente nel DB
			}


		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#modificaPreferenzeGeneriche(unisa.gps.etour.bean.BeanPreferenzeGeneriche)
	 */
	public boolean modificaPreferenzeGeneriche(BeanPreferenzeGeneriche pPreferenzeGenericheNuove) throws RemoteException
	{
		try
		{
			boolean checkDati = ControlloDati.checkBeanPreferenzeGeneriche(pPreferenzeGenericheNuove);

			if (checkDati)
			{ // Se il controllo dei dati è positivo
				return prefGenTurista.modificaPreferenzaGenerica(pPreferenzeGenericheNuove);
			}
			else
			{
				return false; // Errore nei dati
			}

		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#ottieniPreferenzeDiRicerca(int)
	 */
	public BeanPreferenzaDiRicerca[] ottieniPreferenzeDiRicerca(int pIdTurista) throws RemoteException
	{
		//Array contenente l'elenco delle preferenze di ricerca del turista con ID = pIdTurista
		BeanPreferenzaDiRicerca[] preferenze = null;
		
		try
		{
			//**Conversione da arraylist (tipo di ritorno del metodo "ottieniPreferenzeDiRicerca") a array semplice**
			ArrayList<BeanPreferenzaDiRicerca> listaPreferenze = prefRicTurista.ottieniPreferenzeDiRicercaDelTurista(pIdTurista);
			preferenze = new BeanPreferenzaDiRicerca[listaPreferenze.size()];
			preferenze = listaPreferenze.toArray(preferenze);
			//**Fine conversione**
		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		
		return preferenze;
		
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#ottieniPreferenzeGeneriche(int)
	 */
	public BeanPreferenzeGeneriche ottieniPreferenzeGeneriche(int pIdTurista) throws RemoteException
	{
		try
		{
			return prefGenTurista.ottieniPreferenzaGenerica(pIdTurista);
		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.GestioneTuristaComune#modificaTurista(unisa.gps.etour.bean.BeanTurista)
	 */
	public boolean modificaTurista(BeanTurista pprofiloTurista) throws RemoteException
	{
		try
		{
			//Variabile booleana che conterrà true,se il bean è corretto, false altrimenti
			boolean checkDati = ControlloDati.checkBeanTurista(pprofiloTurista);

			if (checkDati)
			{ // Se il controllo dei dati è positivo
				return profiloTurista.modificaTurista(pprofiloTurista);
			}
			else
			{
				return false; // Errore nei dati
			}

		}
		catch (SQLException e)
		{
			// se dal data layer viene lanciata una eccezione SQLException
			// si lancia l'eccezione remota RemoteException
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#ottieniBeniCulturaliVisitati(int)
	 */
	public BeanVisitaBC[] ottieniBeniCulturaliVisitati(int pIdTurista) throws RemoteException
	{
		BeanVisitaBC[] visitati = null;
		if (pIdTurista > 0)
		{
			try
			{
				ArrayList<BeanVisitaBC> listavisitati = visitatiBC.ottieniListaVisitaBCTurista(pIdTurista);
				visitati = new BeanVisitaBC[listavisitati.size()];
				visitati = listavisitati.toArray(visitati);
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}

		}
		return visitati;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#ottieniPuntiDiRistoroVisitati(int)
	 */
	public BeanVisitaPR[] ottieniPuntiDiRistoroVisitati(int pIdTurista) throws RemoteException
	{
		//Array contenente l'elenco dei punti di ristoro visitati dal turista con id "pIdTurista"
		BeanVisitaPR[] visitati = null;
		if (pIdTurista > 0)
		{
			try
			{
				ArrayList<BeanVisitaPR> listavisitati = visitatiPR.ottieniListaVisitaPRTurista(pIdTurista);
				visitati = new BeanVisitaPR[listavisitati.size()];
				visitati = listavisitati.toArray(visitati);
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}

		}
		return visitati;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciBeneCulturaleVisitato(unisa.gps.etour.bean.BeanVisitaBC)
	 */
	public boolean inserisciBeneCulturaleVisitato(BeanVisitaBC pVisitaBC) throws RemoteException
	{
		if (ControlloDati.checkBeanVisitaBC(pVisitaBC))
		{
			try
			{
				
				return visitatiBC.inserisciVisitaBC(pVisitaBC);
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciPuntoDiRistoroVisitato(unisa.gps.etour.bean.BeanVisitaPR)
	 */
	public boolean inserisciPuntoDiRistoroVisitato(BeanVisitaPR pVisitaPR) throws RemoteException
	{
		if (ControlloDati.checkBeanVisitaPR(pVisitaPR))
		{
			try
			{
				return visitatiPR.inserisciVisitaPR(pVisitaPR);
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciBeneCulturalePreferito(int,
	 *      int)
	 */
	public boolean inserisciBeneCulturalePreferito(int pIdTurista,int pIdBeneCulturale) throws RemoteException
	{
		if (pIdTurista > 0 && pIdBeneCulturale > 0)
		{
			try
			{
				return profiloTurista.inserisciBeneCulturalePreferito(pIdTurista, pIdBeneCulturale);
			}
			catch (SQLException e)
			{

				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#inserisciPuntoDiRistoroPreferito(int,
	 *      int)
	 */
	public boolean inserisciPuntoDiRistoroPreferito(int pIdTurista,int pIdPuntoDiRistoro) throws RemoteException
	{
		if (pIdTurista > 0 && pIdPuntoDiRistoro > 0)
		{
			try
			{
				return profiloTurista.inserisciPuntoDiRistoroPreferito(pIdTurista, pIdPuntoDiRistoro);
			}
			catch (SQLException e)
			{

				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#cancellaBeneCulturalePreferito(int,
	 *      int)
	 */
	public boolean cancellaBeneCulturalePreferito(int pIdTurista,int pIdBeneCulturale) throws RemoteException
	{
		if (pIdTurista > 0 && pIdBeneCulturale > 0)
		{
			try
			{
				return profiloTurista.cancellaBeneCulturalePreferito(pIdTurista, pIdBeneCulturale);
			}
			catch (SQLException e)
			{

				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#cancellaPuntoDiRistoroPreferito(int,
	 *      int)
	 */
	public boolean cancellaPuntoDiRistoroPreferito(int pIdTurista,int pIdPuntoDiRistoro) throws RemoteException
	{
		if (pIdTurista > 0 && pIdPuntoDiRistoro > 0)
		{
			try
			{
				return profiloTurista.cancellaPuntoDiRistoroPreferito(pIdTurista, pIdPuntoDiRistoro);
			}
			catch (SQLException e)
			{

				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return false;
	}

	/* (non-Javadoc)
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#ottieniBeniCulturaliPreferiti(int)
	 */
	public BeanBeneCulturale[] ottieniBeniCulturaliPreferiti(int pIdTurista) throws RemoteException
	{
		if (pIdTurista > 0)
		{
			try
			{
				//Elenco dei beni culturali preferiti del turista cn id = "pIdTurista"
				ArrayList<Integer> listaPreferiti = profiloTurista.ottieniBeniCulturaliPreferiti(pIdTurista);
				//Conversione da arraylist a array semplice
				BeanBeneCulturale[] preferiti = null;
				preferiti = new BeanBeneCulturale[listaPreferiti.size()];
				preferiti = listaPreferiti.toArray(preferiti);
				
				int k = 0; //Contatore di ciclo
				for (Integer i : listaPreferiti)
				{
					//Riempie l'array preferiti con i bean di tutti i beni culturali preferiti dal turista
					preferiti[k++] = beneCulturale.ottieniBeneCulturale(i);
				}
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return null;
	}

	/* (non-Javadoc)
	 * @see unisa.gps.etour.control.GestioneUtentiRegistrati.IGestioneTuristaClient#ottieniPuntiDiRistoroPreferiti(int)
	 */
	public BeanPuntoDiRistoro[] ottieniPuntiDiRistoroPreferiti(int pIdTurista) throws RemoteException
	{
		if (pIdTurista > 0)
		{
			try
			{	
				//Elenco dei punti di ristoro preferiti del turista cn id = "pIdTurista"
				ArrayList<Integer> listaPreferiti = profiloTurista.ottieniPuntoDiRistoroPreferiti(pIdTurista);
				
				//Conversione da arraylist a array semplice
				BeanPuntoDiRistoro[] preferiti = null;
				preferiti = new BeanPuntoDiRistoro[listaPreferiti.size()];
				preferiti = listaPreferiti.toArray(preferiti);
				
				int k = 0; //Contatore di ciclo
				for (Integer i : listaPreferiti)
				{
					//Riempie l'array preferiti con i bean di tutti i beni culturali preferiti dal turista
					preferiti[k++] = puntoDiRistoro.ottieniPuntoDiRistoro(i);
				}
			}
			catch (SQLException e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
			}
			catch (Exception e)
			{
				throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
			}
		}
		return null;
	}
}

