package unisa.gps.etour.control.GestioneUtentiRegistrati;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.sql.SQLException;

import unisa.gps.etour.bean.BeanTurista;
import unisa.gps.etour.repository.DBTurista;
import unisa.gps.etour.repository.IDBTurista;
import unisa.gps.etour.util.MessaggiErrore;

/**
 * Classe che implementa le operazioni comuni per Operatore Agenzia e Turista
 * ossia modificaTurista e ottieniTurista
 * 
 * @author Morelli Giuseppe
 * @version 0.1 � 2007 eTour Project - Copyright by SE@SA Lab DMI � University
 *          of Salerno
 */
public class GestioneTuristaComune extends UnicastRemoteObject implements
		IGestioneTuristaComune
{

	protected IDBTurista turista;

	// Costruttore che richama a sua volta il costruttore della classe
	// UnicastRemoteObject per la connessione via RMI
	// e istanzia la connessione al database
	public GestioneTuristaComune() throws RemoteException
	{
		super();
		// Connessione al Database
		try
		{
			turista = new DBTurista();
		}
		// Eccezione nella connessione al Database
		catch (Exception e)
		{
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
	}

	// Metodo che permette di modificare i dati di un Turista tramite i suoi
	// dati
	public boolean modificaTurista(BeanTurista pProfiloTurista)
			throws RemoteException
	{
		// Controllo la validità dei dati passati
		if ((pProfiloTurista == null)
				|| (!(pProfiloTurista instanceof BeanTurista)))
			throw new RemoteException(MessaggiErrore.ERRORE_FORMATO_BEAN);
		// Esecuzione dell'operazione di modifica
		try
		{
			// se le modifiche sono state effettuate si restituisce true
			if (turista.modificaTurista(pProfiloTurista))
				return true;
		}
		// Eccezione nelle operazioni sul database
		catch (SQLException e)
		{
			// se il data layer invia una eccezione si lancia l'eccezione remota
			System.out.println("Errore nel metodo modificaTurista: "
					+ e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezione imprevista causata da altri fattori
		catch (Exception ee)
		{
			System.out.println("Errore nel metodo modificaTurista: "
					+ ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		// se non sono state rilevate eccezioni ma le modifiche non sono
		// state effettuate si restituisce false
		return false;
	}

	// Metodo che permette di ottenere il bean con i dati del Turista
	// identificato tramite
	// il parametro passato
	public BeanTurista ottieniTurista(int pIdTurista) throws RemoteException
	{
		// Controllo la validità dell'identificativo
		if (pIdTurista < 0)
			throw new RemoteException(MessaggiErrore.ERRORE_DATI);
		BeanTurista toReturn = null;// variabile di ritorno
		// Recupero i dati
		try
		{
			// si richiede al data layer di restituire il bean del turista
			// con id uguale a pIdTurista
			toReturn = turista.ottieniTurista(pIdTurista);
			if (toReturn == null)
				throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezione nelle operazioni sul Database
		catch (SQLException e)
		{
			// se il data layer invia una eccezione si lancia l'eccezione remota
			System.out.println("Errore nel metodo ottieniTurista: "
					+ e.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_DBMS);
		}
		// Eccezioni impreviste causate da altri fattori
		catch (Exception ee)
		{
			System.out.println("Errore nel metodo ottieniTurista: "
					+ ee.toString());
			throw new RemoteException(MessaggiErrore.ERRORE_SCONOSCIUTO);
		}
		// restituisce il risultato
		return toReturn;
	}
}
