package unisa.gps.etour.repository;

import java.sql.SQLException;
import java.util.ArrayList;

import unisa.gps.etour.bean.BeanBanner;

/**
 * Interfaccia per la gestione dei banner sul database
 * 
 * @author Miranda Mauro
 * @version 0.1 � 2007 eTour Project - Copyright by SE@SA Lab DMI � University
 *          of Salerno
 */

public interface IDBBanner
{
	/**
	 * Aggiunge un banner nel database
	 * 
	 * @param pBanner bean contenente le informazioni del banner
	 * @throws SQLException
	 */
	public boolean inserisciBanner(BeanBanner pBanner) throws SQLException;

	/**
	 * Modifica il contenuto di un banner e restituisce il contenuto prima della
	 * modifica
	 * 
	 * @param pBanner Bean che contiene le nuove informazioni del banner
	 * @return True se c'e' stata una modifica false altrimenti
	 * @throws SQLException
	 */
	public boolean modificaBanner(BeanBanner pBanner) throws SQLException;

	/**
	 * Elimina un banner dal database e lo restituisce
	 * 
	 * @param pIdBanner Identificativo BeanBanner
	 * @return True se e' stato eliminato false altrimenti
	 * @throws SQLException
	 */
	public boolean cancellaBanner(int pIdBanner) throws SQLException;

	/**
	 * Restituisce una lista dei banner di un punto di ristoro, se l'id del
	 * punto di ristoro e' uguale a -1 verra' restituita la lista completa dei
	 * banner
	 * 
	 * @param pIdPuntoDiRistoro Id del punto di ristoro da cui ottenere la lista
	 *            dei banner
	 * @return Lista dei banner collegati al Punto di ristoro
	 * @throws SQLException
	 */
	public ArrayList<BeanBanner> ottieniBanner(int pIdPuntoDiRistoro)
			throws SQLException;

	/**
	 * Metodo che restituisce un banner dato il suo id
	 * 
	 * @param pIdBanner Identificativo del banner da restituire
	 * @return Banner trovato nel database, null se non c'e' corrispondenza
	 * @throws SQLException 
	 */
	public BeanBanner ottieniBannerDaID(int pIdBanner) throws SQLException;
}
