package unisa.gps.etour.repository;

import java.sql.SQLException;
import java.util.ArrayList;

import unisa.gps.etour.bean.BeanBeneCulturale;
import unisa.gps.etour.bean.BeanTag;
import unisa.gps.etour.util.Punto3D;

/**
 * Interfaccia per la gestione dei Beni Culturali sul database
 * 
 * @author Miranda Mauro
 * @version 0.1 � 2007 eTour Project - Copyright by SE@SA Lab DMI � University
 *          of Salerno
 */

public interface IDBBeneCulturale
{
	/**
	 * Aggiunge un Bene Culturale dato in input
	 * 
	 * @param pBene Bene Culturale da inserire nel database
	 * @throws SQLException
	 */
	public boolean inserisciBeneCulturale(BeanBeneCulturale pBene)
			throws SQLException;

	/**
	 * Modifica le informzioni del bene culturale
	 * 
	 * @param pBene Contiene le informazioni da modificare nel database
	 * @throws SQLException
	 * @return True se c'e' stata una modifica false altrimenti
	 */
	public boolean modificaBeneCulturale(BeanBeneCulturale pBene)
			throws SQLException;

	/**
	 * Elimina un bene culturale dal database
	 * 
	 * @param pIdBene Identificativo Bene culturale da eliminare
	 * @throws SQLException
	 * @return True se e' stato cancellato false altrimenti
	 */
	public boolean cancellaBeneCulturale(int pIdBene) throws SQLException;

	/**
	 * Restituisce il bene culturale con id dato in input
	 * 
	 * @param pId Bene culturale da estrarre dal database
	 * @throws SQLException
	 * @return Bene culturale ottenuto dal database
	 */
	public BeanBeneCulturale ottieniBeneCulturale(int pId) throws SQLException;

	/**
	 * Ricerca. Restituisce la lista di beni culturali che hanno nel nome o
	 * nella descrizione la stringa data in input, filtrati secondo i tag e la
	 * distanza massima. La lista restituita contiene il numero di beni dato in input. 
	 * Per scorrere la reale lista, che potrebbe contenere piu' di
	 * dieci elementi, si utilizza il paramtro numPagina.
	 * 
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del bene culturale
	 * @param pTags Lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pNumPagina Il numero di pagina che si vuole visualizzare. O per la
	 *            1� pagina (i primi 10 risultati), 1 per la 2� pagina (i
	 *            risultati dal 11 al 20) ecc...
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al bene da ricercare
	 * @param pNumeroElementiPerPagina Numero di elementi da restituire per pagina
	 * @throws SQLException
	 * @return lista contenete dieci beni culturali
	 */
	public ArrayList<BeanBeneCulturale> ricerca(String pKeyword,
			ArrayList<BeanTag> pTags, int pNumPagina,int pNumeroElementiPerPagina, Punto3D pPosizione,
			double pDistanzaMassima) throws SQLException;

	/**
	 * Ricerca avanzata. Restituisce la lista di beni culturali che hanno nel
	 * nome o nella descrizione la stringa data in input, ordinati secondo le
	 * preferenze del turista e filtrati secondo i tag e la distanza massima. La
	 * lista restituita contiene il numero di beni dato in input. Per scorrere
	 * la reale lista, che potrebbe contenere piu' elementi, si
	 * utilizza il paramtro numPagina.
	 * 
	 * @param pIdTurista Identificativo del turista che ha effettuato la ricerca
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del bene culturale
	 * @param pTags Lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pNumPagina Il numero di pagina che si vuole visualizzare. O per la
	 *            1� pagina (i primi 10 risultati), 1 per la 2� pagina (i
	 *            risultati dal 11 al 20) ecc...
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al bene da ricercare
	 * @param pNumeroElementiPerPagina Numero di elementi da restituire per pagina
	 * @throws SQLException
	 * @return lista contenete dieci beni culturali
	 */
	public ArrayList<BeanBeneCulturale> ricercaAvanzata(int pIdTurista,
			String pKeyword, ArrayList<BeanTag> pTags, int pNumPagina, int pNumeroElementiPerPagina,
			Punto3D pPosizione, double pDistanzaMassima) throws SQLException;

	/**
	 * Metodo per ottenere il numero di elementi per una ricerca avanzata.
	 * 
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del bene culturale
	 * @param pTags Lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al bene da ricercare
	 * @throws SQLException
	 * @return Numero di pagine totali.
	 */
	public int ottieniNumeroElementiRicerca(String pKeyword,
			ArrayList<BeanTag> pTags, Punto3D pPosizione,
			double pDistanzaMassima) throws SQLException;

	/**
	 * Metodo per ottenere il numero di elementi per una ricerca avanzata.
	 * 
	 * @param pIdTurista identificativo del turista che ha effettuato la ricerca
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del bene culturale
	 * @param pTags lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al bene da ricercare
	 * @throws SQLException
	 * @return numero di pagine totali.
	 */
	public int ottieniNumeroElementiRicercaAvanzata(int pIdTurista,
			String pKeyword, ArrayList<BeanTag> pTags, Punto3D pPosizione,
			double pDistanzaMassima) throws SQLException;
	/**
	 * Restituisce la lista di tutti i beni culturali
	 * 
	 * @throws SQLException
	 * @return Lista di tutti i beni culturali
	 */
	public ArrayList<BeanBeneCulturale> ottieniListaBC() throws SQLException;
}
