package unisa.gps.etour.repository;

import java.sql.SQLException;
import java.util.ArrayList;

import unisa.gps.etour.bean.BeanPuntoDiRistoro;
import unisa.gps.etour.bean.BeanTag;
import unisa.gps.etour.util.Punto3D;


/**
 * Interfaccia per la gestione di Punto di ristoro nel database
 * 
 * @author Martone Giuseppe
 * @version 0.1 � 2007 eTour Project - Copyright by SE@SA Lab DMI � University
 *          of Salerno
 */
public interface IDBPuntoDiRistoro
{
	/**
	 * Aggiunge un punto di ristoro
	 * 
	 * @param pPuntoDiRistoro Punto di ristoro da aggiungere
	 * @throws SQLException
	 */
	public boolean inserisciPuntoDiRistoro(BeanPuntoDiRistoro pPuntoDiRistoro)
			throws SQLException;

	/**
	 * Modifica un punto di ristoro
	 * 
	 * @param pPuntoDiRistoro Punto di ristoro da modificare
	 * @throws SQLException
	 * @return True se e' stata modificata false altrimenti
	 */
	public boolean modificaPuntoDiRistoro(BeanPuntoDiRistoro pPuntoDiRistoro)
			throws SQLException;

	/**
	 * Elimina un punto di ristoro
	 * 
	 * @param pIdPuntoDiRistoro Identificativo Punto di ristoro da eliminare
	 * @throws SQLException
	 * @return True se e' stata cancellata false altrimenti
	 */
	public boolean cancellaPuntoDiRistoro(int pIdPuntoDiRistoro)
			throws SQLException;

	/**
	 * Restituisce i dati di un punto di ristoro con l'id dato come argomento
	 * 
	 * @param pId Identificativo del punto di ristoro
	 * @throws SQLException
	 * @return Punto di ristoro
	 */
	public BeanPuntoDiRistoro ottieniPuntoDiRistoro(int pId)
			throws SQLException;

	/**
	 * Ricerca avanzata. Restituisce la lista di punti di ristoro che hanno nel
	 * nome o nella descrizione la stringa data in input, ordinati secondo le
	 * preferenze del turista, filtrati secondo i tag e secondo la distanza
	 * massima. La lista restituita contiene solo il numero dei punti di ristoro dati in input. 
	 * Per scorrere la reale lista, che potrebbe contenere piu' elementi, si 
	 * utilizza il paramtro numPagina.
	 * 
	 * @param pIdTurista Id del turista che ha effettuato la ricerca
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del punto di ristoro
	 * @param pTags lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pNumeroPagina Il numero di pagina che si vuole visualizzare. O per
	 *            la 1� pagina (i primi 10 risultati), 1 per la 2� pagina (i
	 *            risultati dal 11 al 20) ecc... *
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param int pNumeroElementiPerPagina Numero di elementi da restituire
	 * @param pDistanzaMassima Distanza massima dall'utente al punto di ristoro
	 *            da ricercare
	 * @throws SQLException
	 * @return lista contenete dieci punti di ristoro
	 */
	public ArrayList<BeanPuntoDiRistoro> ricercaAvanzata(int pIdTurista,
			String pKeyword, ArrayList<BeanTag> pTags, int pNumeroPagina,int pNumeroElementiPerPagina,
			Punto3D pPosizione, double pDistanzaMassima) throws SQLException;

	/**
	 * Metodo per ottenere il numero di elementi per una ricerca avanzata.
	 * 
	 * @see ricercaAvanzata()
	 * @param pIdTurista Id del turista che ha effettuato la ricerca
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del punto di ristoro
	 * @param pTags lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati. *
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al punto di ristoro
	 *            da ricercare
	 * @throws SQLException
	 * @return numero di pagine totali.
	 */
	public int ottieniNumeroElementiRicercaAvanzata(int pIdTurista,
			String pKeyword, ArrayList<BeanTag> pTags, Punto3D pPosizione,
			double pDistanzaMassima) throws SQLException;

	/**
	 * Ricerca. Restituisce la lista di punti di ristoro che hanno nel nome o
	 * nella descrizione la stringa data in input, filtrati secondo i tag e
	 * secondo la distanza massima. La lista restituita contiene il numero dei
	 * punti di ristoro dati in input. Per scorrere la reale lista, che
	 * potrebbe contenere piu' elementi, si utilizza il paramtro
	 * numPagina.
	 * 
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del punto di ristoro
	 * @param pTags lista di tag utilizzaiti come filtro per la ricerca. il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pNumeroPagina Il numero di pagina che si vuole visualizzare. O per
	 *            la 1� pagina (i primi 10 risultati), 1 per la 2� pagina (i
	 *            risultati dal 11 al 20) ecc... *
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al punto di ristoro
	 * @param int pNumeroElementiPerPagina Numero di elementi da restituire
	 * @throws SQLException
	 * @return lista contenete dieci punti di ristoro
	 */
	public ArrayList<BeanPuntoDiRistoro> ricerca(String pKeyword,
			ArrayList<BeanTag> pTags, int pNumeroPagina,int pNumeroElementiPerPagina, Punto3D pPosizione,
			double pDistanzaMassima) throws SQLException;

	/**
	 * Metodo per ottenere il numero elementi per una ricerca avanzata.
	 * 
	 * @see ricerca()
	 * @param pUsernameTurista username del turista che ha effettuato la ricerca
	 * @param pKeyword Stringa che contiene la parola chiave da ricercare nel
	 *            nome o nella descrizione del punto di ristoro
	 * @param pTags lista di tag utilizzaiti come filtro per la ricerca. Il
	 *            numero massimo di tag da inserire non deve superare le cinque
	 *            unita'. In caso si superi questo numero gli altri tag in
	 *            eccesso verrano ignorati.
	 * @param pPosizione Posizione dell'utente che ha effettuato la ricerca
	 * @param pDistanzaMassima Distanza massima dall'utente al punto di ristoro
	 *            da ricercare
	 * @throws SQLException
	 * @return numero di pagine totali.
	 */
	public int ottieniNumeroElementiRicerca(String pKeyword,
			ArrayList<BeanTag> pTags, Punto3D pPosizione,
			double pDistanzaMassima) throws SQLException;

	/**
	 * Restituisce la lista di tutti i punti di ristoro
	 * 
	 * @throws SQLException
	 * @return Lista di tutti i punti di ristoro
	 */
	public ArrayList<BeanPuntoDiRistoro> ottieniListaPR() throws SQLException;
}
