﻿package unisa.gps.etour.repository;

import java.sql.SQLException;
import java.util.ArrayList;

import unisa.gps.etour.bean.BeanBeneCulturale;
import unisa.gps.etour.bean.BeanTurista;

/**
 * Interfaccia per la gestione del turista nel database
 * 
 * @author Miranda Mauro
 * @version 0.1 � 2007 eTour Project - Copyright by SE@SA Lab DMI � University
 *          of Salerno
 */
public interface IDBTurista
{
	/**
	 * Aggiunge un turista
	 * 
	 * @param pTurista Turista da aggiungere
	 * @throws SQLException
	 */
	public boolean inserisciTurista(BeanTurista pTurista) throws SQLException;

	/**
	 * Modifica un turista
	 * 
	 * @param pTurista Turista da modificare
	 * @throws SQLException
	 * @return True se e' stato modificato false altrimenti
	 */
	public boolean modificaTurista(BeanTurista pTurista) throws SQLException;

	/**
	 * Elimina un turista dal database
	 * 
	 * @param pIdTurista Identificatio Turista da eliminare
	 * @throws SQLException
	 * @return True se e' stata modificata false altrimenti
	 */
	public boolean cancellaTurista(int pIdTurista) throws SQLException;

	/**
	 * Restituisce i dati del Turista
	 * 
	 * @param pUsername Username del turista
	 * @throws SQLException
	 * @return Dati del turista
	 */
	public BeanTurista ottieniTurista(String pUsername) throws SQLException;

	/**
	 * Associa un bene culturale preferito al turista
	 * 
	 * @param pIdTurista Identificativo del turista
	 * @param pIdBeneCulturale Identificativo del bene culturale
	 * @throws SQLException
	 */
	public boolean inserisciBeneCulturalePreferito(int pIdTurista,
			int pIdBeneCulturale) throws SQLException;

	/**
	 * Associa un punto di ristoro preferito al turista
	 * 
	 * @param pIdTurista Identificativo del turista
	 * @param pIdPuntoDiRistoro Identificativo del bene culturale
	 * @throws SQLException
	 */
	public boolean inserisciPuntoDiRistoroPreferito(int pIdTurista,
			int pIdPuntoDiRistoro) throws SQLException;

	/**
	 * Elimina un bene culturale preferito
	 * 
	 * @param pIdTurista Identificativo del turista
	 * @param pIdBeneCulturale Identificativo del bene culturale
	 * @throws SQLException
	 * @return True se e' stato modificato false altrimenti
	 */
	public boolean cancellaBeneCulturalePreferito(int pIdTurista,
			int pIdBeneCulturale) throws SQLException;

	/**
	 * Elimina un punto di ristoro preferito
	 * 
	 * @param pIdTurista Identificativo del turista
	 * @param pIdPuntoDiRistoro Identificativo del bene culturale
	 * @throws SQLException
	 * @return True se e' stato cancellato false altrimenti
	 */
	public boolean cancellaPuntoDiRistoroPreferito(int pIdTurista,
			int pIdPuntoDiRistoro) throws SQLException;

	/**
	 * Restituisce un arraylist di Turisti che hanno l'username simile a quello
	 * dato come argomento
	 * 
	 * @param pUsernameTurista Usrername del turista da ricercare
	 * @throws SQLException
	 * @return Dati dei Turisti
	 */
	public ArrayList<BeanTurista> ottieniTuristi(String pUsernameTurista)
			throws SQLException;

	/**
	 * Restituisce la lista dei turisti attivati/disattivati
	 * 
	 * @param pAttivo True seleziona i turisti attivati False quelli disattivati
	 * @return Dati dei Turisti
	 * @throws SQLException
	 */
	public ArrayList<BeanTurista> ottieniTuristi(boolean pAttivo)
			throws SQLException;

	/**
	 * Restituisce i dati del turista con Identificativo uguale a quello dato in
	 * input
	 * 
	 * @param pIdTurista Identificativo del turista da trovare
	 * @return Turista con id uguale a quello in input, Null se non esiste
	 * @throws SQLException
	 */
	public BeanTurista ottieniTurista(int pIdTurista) throws SQLException;

	/**
	 * Restituisce la lista dei beni culturali preferiti da un determinato
	 * Turista
	 * 
	 * @param pIdTurista Identificativo del turista da trovare
	 * @return Lista dei Beni Culturali Preferiti
	 * @throws SQLException
	 */
	public ArrayList<Integer> ottieniBeniCulturaliPreferiti(int pIdTurista)
			throws SQLException;

	/**
	 * Restituisce la lista dei punto di ristoro preferiti da un determinato
	 * Turista
	 * 
	 * @param pIdTurista Identificativo del turista da trovare
	 * @return Lista dei Punto Di Ristoro Preferiti
	 * @throws SQLException
	 */
	public ArrayList<Integer> ottieniPuntoDiRistoroPreferiti(int pIdTurista)
			throws SQLException;

}
