package unisa.gps.etour.control.GestioneBeniCulturali;

import java.rmi.RemoteException;
import java.util.ArrayList;
import unisa.gps.etour.bean.BeanBeneCulturale;
import unisa.gps.etour.bean.BeanVisitaBC;

/**
 * Interfaccia per le operazioni peculiari sui beni culturali da parte
 * dell'Operatore Agenzia.
 * 
 * @author De Simone Michelangelo
 * @version 0.1 &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *          University of Salerno
 */
public interface IGestioneBeniCulturaliAgenzia extends
		IGestioneBeniCulturaliComune
{
	/**
	 * Metodo per l'inserimento di un nuovo bene culturale
	 * 
	 * @param pBeneCulturale Il bean grezzo da inserire nel database
	 * @return boolean L'esito dell'operazione; true se &egrave; andata a buon fine, false altrimenti
	 * @throws RemoteException Eccezione nel flusso
	 */
	public boolean inserisciBeneCulturale(BeanBeneCulturale pBeneCulturale) throws RemoteException;

	/**
	 * Metodo per la cancellazione di un bene culturale tramite id
	 * 
	 * @param pBeneCulturaleID Id del bean da cancellare
	 * @return boolean L'esito dell'operazione; true se &egrave; andata a buon fine, false altrimenti
	 * @throws RemoteException Eccezione nel flusso
	 */
	public boolean cancellaBeneCulturale(int pBeneCulturaleID) throws RemoteException;

	/**
	 * Metodo per la restituzione di tutti i beni culturali presenti nel
	 * database
	 * 
	 * @return ArrayList Tutti i bean presenti nel database
	 * @throws RemoteException Eccezione nel flusso
	 */
	public ArrayList<BeanBeneCulturale> ottieniBeniCulturali() throws RemoteException;

	/**
	 * Metodo per l'aggiornamento (o modifica) dei dati di un bene culturale
	 * 
	 * @param pBeneCulturale Il bean con le nuove informazioni del bene culturale
	 * @return boolean L'esito dell'operazione; true se &egrave; andata a buon fine, false altrimenti
	 * @throws RemoteException Eccezione nel flusso
	 */
	public boolean modificaBeneCulturale(BeanBeneCulturale pBeneCulturale) throws RemoteException;

	/**
	 * Metodo per l'impostazione di un tag ad un certo bene culturale
	 *
	 * @param pBeneCulturaleID L'identificativo del bene culturale al quale aggiungere il tag
	 * @param pTagID L'identificativo del tag da aggiungere al bene culturale indicato
	 * @return boolean L'esito dell'operazione; true se &egrave; andata a buon fine, false altrimenti
	 * @throws RemoteException Eccezione nel flusso
	 */
	public boolean aggiungiTagBeneCulturale(int pBeneCulturaleID, int pTagID) throws RemoteException;
	
	/**
	 * Metodo per la rimozione di un tag da un certo bene culturale
	 * Affinche' l'operazione vada a buon fine &egrave; necessario che il bene culturale abbia
	 * effettivamente impostato il tag specificato
	 *
	 * @param pBeneCulturaleID L'identificativo del bene culturale dal quale rimuovere il tag
	 * @param pTagID L'identificativo del tag da rimuovere dal bene culturale indicato
	 * @return boolean L'esito dell'operazione; true se &egrave; andata a buon fine, false altrimenti
	 * @throws RemoteException Eccezione nel flusso
	 */
	public boolean rimuoviTagBeneCulturale(int pBeneCulturaleID, int pTagID) throws RemoteException;
}
