﻿package unisa.gps.etour.control.GestionePuntiDiRistoro;

import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.HashMap;

import unisa.gps.etour.bean.BeanConvenzione;
import unisa.gps.etour.bean.BeanPuntoDiRistoro;
import unisa.gps.etour.bean.BeanVisitaPR;

/**
 * Interfaccia di Punti di Ristoro dal lato dell'agenzia
 * 
 * @author Morelli Giuseppe
 * @version 0.1 © 2007 eTour Project - Copyright by SE@SA Lab DMI – University
 *          of Salerno
 */
public interface IGestionePuntiDiRistoroAgenzia extends
		IGestionePuntiDiRistoroComune
{

	/**
	 * Metodo per l'inserimento di un nuovo Punto di Ristoro
	 * 
	 * @param pPuntoDiRistoro contenente tutti i dati del Punto di Ristoro da
	 *            aggiungere
	 * @throws RemoteException Eccezione Remota
	 */
	public boolean inserisciPuntoDiRistoro(BeanPuntoDiRistoro pPuntoDiRistoro)
			throws RemoteException;

	/**
	 * Metodo per la cancellazione di un Punto di Ristoro tramite l'ID
	 * 
	 * @param pIDPuntoDiRistoro per l'identificazione univoca del Punto di
	 *            Ristoro
	 * @throws RemoteException Eccezione Remota
	 */
	public boolean cancellaPuntoDiRistoro(int pPuntoDiRistoroID)
			throws RemoteException;

	/**
	 * Metodo per la restituzione di tutti i Punti di Ristoro del DataBase
	 * 
	 * @return ArrayList contenente tutti i bean dei Punti di Ristoro presenti
	 *         nel DataBase
	 * @throws RemoteException Eccezione Remota
	 */
	public ArrayList<BeanPuntoDiRistoro> ottieniPuntiDiRistoro()
			throws RemoteException;

	/**
	 * Metodo per la restituzione di tutti i punti di ristoro con convenzione
	 * attiva o meno
	 * 
	 * @param statoConvenzione Booleano per il tipo di Punti di Ristoro da
	 *            ottenere (convenzionati o meno)
	 * @return ArrayList contenente tutti i bean dei Punti di Ristoro presenti
	 *         nel DataBase a seconda dello stato della convenzione
	 * @throws RemoteException Eccezione Remota
	 */
	public ArrayList<BeanPuntoDiRistoro> ottieniPuntiDiRistoro(
			boolean statoConvenzione) throws RemoteException;

	/**
	 * Metodo per l'inserimento di una nuova convenzione per un certo Punto di
	 * Ristoro
	 * 
	 * @param pPuntoDiRistoroID Intero che identifica univocamente il Punto di
	 *            Ristoro
	 * @param pConv Convenzione che si intende attivare (Il parametro ID del
	 *            punto di ristoro crea ridondanza ma è utile per la sicurezza
	 *            dei dati)
	 * @return Booleano per conferma dell'avvenuta operazione
	 * @throws RemoteException Eccezione Remota
	 */
	public boolean attivaConvenzione(int pPuntoDiRistoroID,
			BeanConvenzione pConv) throws RemoteException;

	/**
	 * Metodo per ottenere tutti i feedback associati ad un certo Punto di
	 * Ristoro
	 * 
	 * @param pPuntoDiRistoroID Identificativo univoco del Punto Di Ristoro di
	 *            cui ottenere i feedback
	 * @return HashMap contenente come chiave i bean dei feedback e come valore
	 *         il turista che ha rilasciato il feedback
	 * @throws RemoteException Eccezione Remota
	 */
	public HashMap<BeanVisitaPR, String> ottieniFeedbackPuntoDiRistoro(
			int pPuntoDiRistoroID) throws RemoteException;

	/**
	 * Metodo per l'aggiornamento (o modifica) dei dati di un Punto di Ristoro
	 * 
	 * @param pPuntoDiRistoroID per l'identificazione univoca del Punto di
	 *            Ristoro da modificare
	 * @param pPuntoDiRistoroAggiornato contenente i nuovi dati da salvare
	 * @return Booleano con valore true se l'operazione è andata a buon fine,
	 *         false altrimenti
	 * @throws RemoteException Eccezione Remota
	 */
	public boolean modificaPuntoDiRistoro(
			BeanPuntoDiRistoro pPuntoDiRistoroAggiornato)
			throws RemoteException;

	/**
	 * Metodo che permette di inserire un Tag utile alla ricerca per un Punto di
	 * Ristoro
	 * 
	 * @param pPuntoDiRistoroId Identificativo univoco del Punto Di Ristoro
	 * @param pTagId Identificativo univoco del Tag da inserire
	 * @return Booleano con valore true se l'operazione è andata a buon fine,
	 *         false altrimenti
	 * @throws RemoteException Eccezione Remota
	 */
	public boolean inserisciTagPuntoDiRistoro(int pPuntoDiRistoroId, int pTagId)
			throws RemoteException;

	/**
	 * Metodo che permette di cancellare un Tag utile alla ricerca per un Punto
	 * Di Ristoro
	 * 
	 * @param pPuntoDiRistoroId Identificativo univoco del Punto Di Ristoro
	 * @param pTagId Identificativo univoco del Tag da inserire
	 * @return Booleano con valore true se l'operazione è andata a buon fine,
	 *         false altrimenti
	 * @throws RemoteException Eccezione Remota
	 */
	public boolean cancellaTagPuntoDiRistoro(int pPuntoDiRistoroId, int pTagId)
			throws RemoteException;

}
