package unisa.gps.etour.gui.operatoreagenzia.tables;

import java.awt.Component;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;
import unisa.gps.etour.gui.operatoreagenzia.Home;

/**
 * <b>MediaVotiRenderer</b>
 * <p>
 * Questa classe realizza un renderer personalizzato per la media voti di un
 * sito.</b>
 * 
 * @see javax.swing.table.DefaultTableRenderer;
 * @see javax.swing.table.TableCellRenderer;
 * @version 1.0
 * @author Mario Gallo
 */
public class MediaVotiRenderer extends DefaultTableCellRenderer
{

	/**
	 * Metodo che restituisce il componente personalizzato per la
	 * visualizzazione del dato contenuto nella cella di una table.
	 * 
	 * @param JTable pTable - la tabella.
	 * @param Object pValue - il dato.
	 * @param boolean pSelected -
	 *            <ul>
	 *            <li><i>true</i> se la cella � selezionata.
	 *            <li> <i>false</i> altrimenti.
	 *            </ul>
	 * @param boolean pHasFocus -
	 *            <ul>
	 *            <li><i>true</i> se la cella ha il focus.
	 *            <li><i> false</i> altrimenti.
	 *            </ul>
	 * @param int pRow - il numero di riga.
	 * @param int pColumn - il numero di colonna.
	 * @return Component - il componente che personalizza il render della cella.
	 * @throws IllegalArgumentException - se il valore della cella non può
	 *             essere renderizzato da questo renderer.
	 */
	public Component getTableCellRendererComponent(JTable pTable,
			Object pValue, boolean pSelected, boolean pFocus, int pRow,
			int pColumn) throws IllegalArgumentException
	{
		if (!(pValue instanceof Double || pValue instanceof Integer))
		{
			throw new IllegalArgumentException("Valore cella inaspettato.");
		}
		double voto = 0;
		if (pValue instanceof Double)
		{
			voto = (Double) pValue;
		}
		else 
		{
			voto += (Integer) pValue;
		}
		
		JLabel aLabel = new JLabel("");
		aLabel.setHorizontalAlignment(JLabel.CENTER);
		
		if (voto > 4)
		{
			aLabel.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "stella5.gif")));
		}
		else if (voto <= 4 && voto > 3)
		{
			aLabel.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "stella4.gif")));
		}
		else if (voto <= 3 && voto > 2)
		{
			aLabel.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "stella3.gif")));
		}
		else if (voto <= 2 && voto > 1)
		{
			aLabel.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "stella2.gif")));
		}
		else
		{
			aLabel.setIcon(new ImageIcon(getClass().getResource(
					Home.URL_IMAGES + "stella1.gif")));
		}
		return aLabel;

	}

}
