package unisa.gps.etour.gui.operatoreagenzia.tables;

import javax.swing.tree.DefaultMutableTreeNode;

/**
 * <b>PRNode</b>
 * <p>Questa classe realizza un nodo di un jtree per memorizzare
 * le informazioni relative a un punto di ristoro.</p>
 * 
 * @see javax.swing.JTree;
 * @see javax.swing.tree.DefaultMutableTreeNode;
 * @version 1.0
 * @author Mario Gallo
 * 
 */
public class PRNode extends DefaultMutableTreeNode
{
	private int id;
	
	public PRNode()
	{
		super();
	}
	
	/**
	 * Crea un nodo con il nome del punto di ristoro e
	 * il suo id forniti come parametri.
	 * 
	 * @param pNomePR String - il nome del punto di ristoro.
	 * @param pID int - l'id del punto di ristoro.
	 * @throws IllegalArgumentException - se il nome fornito in input non è valido.
	 */
	public PRNode(String pNome, int pID) throws IllegalArgumentException
	{
		super();
		if (pNome == null || pNome.equals(""))
		{
			throw new IllegalArgumentException(
					"Nome del punto di ristoro fornito in input non valido.");
		}
		setUserObject(pNome);
		id = pID;
	}
	
	/**
	 * 
	 * Restituisce l'id del punto di ristoro le cui informazioni
	 * sono memorizzate in questo nodo.
	 *
	 * @return int - l'id del punto di ristoro.
	 */
	public int getID()
	{
		return id;
	}
	
	/**
	 * 
	 * Memorizza l'id del punto di ristoro fornito in input.
	 *
	 * @param pID int - un id di un punto di ristoro.
	 */
	public void setID(int pID)
	{
		id = pID;
	}
	
	/**
	 * 
	 * Ritorna il nome del punto di ristoro.
	 *
	 * @return String - il nome del punto di ristoro.
	 */
	public String getNome()
	{
		return (String) super.getUserObject();
	}
	
	/**
	 * 
	 * Memorizza il nome del punto di ristoro fornito in input.
	 *
	 * @param pNome String - il nome di un punto di ristoro.
	 * @throws IllegalArgumentException - se il nome fornito in input non è valido.
	 */
	public void setNome(String pNome) throws IllegalArgumentException
	{
		if (pNome == null || pNome.equals(""))
		{
			throw new IllegalArgumentException(
					"Nome del punto di ristoro fornito in input non valido.");
		}
		setUserObject(pNome);
	}
}
