package unisa.gps.etour.gui.operatoreagenzia.tables;

import java.awt.Component;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.SwingConstants;
import javax.swing.table.TableCellRenderer;
import unisa.gps.etour.util.Punto3D;

/**
 * <b>Punto3DRenderer</b>
 * <p>Questa classe realizza un renderer personalizzato per gli
 * oggetti di tipo Punto3D.</p>
 * 
 * @see javax.swing.table.TableCellRenderer
 * @see unisa.gps.etour.util.Punto3D
 * @version 1.0
 * @author Mario Gallo
 * 
 * 
 */
public class Punto3DRenderer implements TableCellRenderer
{
	/**
	 * Metodo che restituisce il componente personalizzato per la
	 * visualizzazione del dato contenuto nella cella di una table.
	 * 
	 * @param JTable pTable - la tabella.
	 * @param Object pValue - il dato.
	 * @param boolean pSelected -
	 *            <ul>
	 *            <li><i>true</i> se la cella &egrave; selezionata.
	 *            <li> <i>false</i> altrimenti.
	 *            </ul>
	 * @param boolean pHasFocus -
	 *            <ul>
	 *            <li><i>true</i> se la cella ha il focus.
	 *            <li><i> false</i> altrimenti.
	 *            </ul>
	 * @param int pRow - il numero di riga.
	 * @param int pColumn - il numero di colonna.
	 * @return Component - il componente che personalizza il render della cella.
	 * @throws IllegalArgumentException - se il valore della cella non può
	 *             essere renderizzato da questo renderer.
	 */
	public Component getTableCellRendererComponent(JTable pTable,
			Object pValue, boolean pSelected, boolean pHasFocus, int pRow,
			int pColumn)
	{
		if (!(pValue instanceof Punto3D))
		{
			throw new IllegalArgumentException("Valore Cella inaspettato.");
		}
		Punto3D aPoint = (Punto3D) pValue;
		String punto = aPoint.getLatitudine() + "; "
				+ aPoint.getLongitudine() + "; " + aPoint.getAltitudine();
		JLabel aLabel = new JLabel(punto, SwingConstants.CENTER);
		if (pSelected)
		{
			aLabel.setForeground(pTable.getSelectionForeground());
			aLabel.setBackground(pTable.getSelectionBackground());
		}
		return aLabel;

	}

}
