/**
 * Test case per la classe TestoNewsRenderer
 * 
 * @author Mario Gallo
 * @version 0.1 &#169; 2007 eTour Project - Copyright by SE@SA Lab DMI -
 *          University of Salerno
 */
package unisa.gps.etour.gui.operatoreagenzia.tables.test;

import java.util.Date;
import javax.swing.JTable;
import javax.swing.JTextArea;
import unisa.gps.etour.bean.BeanNews;
import unisa.gps.etour.gui.operatoreagenzia.tables.NewsTableModel;
import unisa.gps.etour.gui.operatoreagenzia.tables.TestoNewsRenderer;
import junit.framework.TestCase;

public class TestoNewsRendererTest extends TestCase
{

	private TestoNewsRenderer renderer;
	private BeanNews aNewsAttiva;
	private BeanNews aNewsScaduta;
	private JTable aTable;

	public TestoNewsRendererTest()
	{
		super();
		renderer = new TestoNewsRenderer();
		aNewsAttiva = new BeanNews("Ecco una news attiva", new Date(),
				new Date(120, 1, 1), 5, 0);
		aNewsScaduta = new BeanNews("Ecco una news scaduta", new Date(),
				new Date(), 5, 0);
		aTable = new JTable(new NewsTableModel());
	}

	/*
	 * Verifica del comportamento del metodo con parametri corretti.
	 */
	public void testGetTableCellRendererParametriCorretti()
	{
		NewsTableModel aModel = (NewsTableModel) aTable.getModel();
		aModel.insertNews(aNewsAttiva);
		aModel.insertNews(aNewsScaduta);

		// Test del renderer con una news attiva.
		JTextArea aArea = (JTextArea) renderer.getTableCellRendererComponent(
				aTable, "Ecco una news attiva", true, true, 0, 0);
		assertEquals(aNewsAttiva.getNews(), aArea.getText());

		// Test del renderer con una news scaduta.
		aArea = (JTextArea) renderer.getTableCellRendererComponent(aTable,
				"Ecco una news scaduta", true, true, 0, 0);
		assertEquals(aNewsScaduta.getNews(), aArea.getText());

	}

	/*
	 * Verifica del comporamento del table con una table senza NewsTableModel
	 * associato.
	 */
	public void testGetTabelCellRendererNoNewsModel()
	{

		JTable anotherTable = new JTable();
		try
		{
			renderer.getTableCellRendererComponent(anotherTable,
					"Ecco una news", true, true, 0, 0);
			fail("Dovrebbe essere sollevata un'eccezione.");
		}
		catch (IllegalArgumentException success)
		{
		}
	}

	/*
	 * Verifica del comportamento del metodo con un parametro a null.
	 */
	public void testGetTableCellRendererParametroNull()
	{
		try
		{
			renderer.getTableCellRendererComponent(aTable, null, true, true, 0,
					0);
			fail("Dovrebbe essere sollevata un'eccezione.");
		}
		catch (IllegalArgumentException success)
		{
		}
	}

	/*
	 * Verifica del comportamento del metodo con un tipo di dato inatteso.
	 */
	public void testGetTableCellRendererTipoInatteso()
	{
		try
		{
			renderer
					.getTableCellRendererComponent(aTable, 12, true, true, 0, 0);
			fail("Dovrebbe essere sollevata un'eccezione.");
		}
		catch (IllegalArgumentException success)
		{
		}

	}

}
